/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
**
** This version of "lempar.c" is modified, slightly, for use by SQLite.
** The only modifications are the addition of a couple of NEVER()
** macros to disable tests that are needed in the case of a general
** LALR(1) grammar but which are always false in the
** specific grammar used by SQLite.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>
#line 51 "parse.y"

#include "sqliteInt.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of this structure is used to store the LIKE,
** GLOB, NOT LIKE, and NOT GLOB operators.
*/
struct LikeOp {
  Token eOperator;  /* "like" or "glob" or "regexp" */
  int not;         /* True if the NOT keyword is present */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** An instance of this structure holds the ATTACH key and the key type.
*/
struct AttachKey { int type;  Token key; };

#line 722 "parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token *pValue){
    pOut->pExpr = sqlite3PExpr(pParse, op, 0, 0, pValue);
    pOut->zStart = pValue->z;
    pOut->zEnd = &pValue->z[pValue->n];
  }
#line 817 "parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    ExprSpan *pOut,     /* Write the result here */
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand */
    ExprSpan *pRight    /* The right operand */
  ){
    pOut->pExpr = sqlite3PExpr(pParse, op, pLeft->pExpr, pRight->pExpr, 0);
    pOut->zStart = pLeft->zStart;
    pOut->zEnd = pRight->zEnd;
  }
#line 873 "parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOut->pExpr = sqlite3PExpr(pParse, op, pOperand->pExpr, 0, 0);
    pOut->zStart = pOperand->zStart;
    pOut->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 892 "parse.y"

  /* A routine to convert a binary TK_IS or TK_ISNOT expression into a
  ** unary TK_ISNULL or TK_NOTNULL expression. */
  static void binaryToUnaryIfNull(Parse *pParse, Expr *pY, Expr *pA, int op){
    sqlite3 *db = pParse->db;
    if( db->mallocFailed==0 && pY->op==TK_NULL ){
      pA->op = (u8)op;
      sqlite3ExprDelete(db, pA->pRight);
      pA->pRight = 0;
    }
  }
#line 920 "parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->pExpr = sqlite3PExpr(pParse, op, pOperand->pExpr, 0, 0);
    pOut->zStart = pPreOp->z;
    pOut->zEnd = pOperand->zEnd;
  }
#line 141 "parse.c"
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    sqlite3ParserTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is sqlite3ParserTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlite3ParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlite3ParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlite3ParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlite3ParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned char
#define YYNOCODE 247
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 67
#define sqlite3ParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlite3ParserTOKENTYPE yy0;
  struct TrigEvent yy30;
  Expr* yy62;
  SrcList* yy151;
  struct LimitVal yy220;
  struct LikeOp yy222;
  IdList* yy240;
  int yy280;
  u8 yy354;
  struct {int value; int mask;} yy359;
  TriggerStep* yy360;
  ExprSpan yy370;
  Select* yy375;
  ExprList* yy418;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlite3ParserARG_SDECL Parse *pParse;
#define sqlite3ParserARG_PDECL ,Parse *pParse
#define sqlite3ParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlite3ParserARG_STORE yypParser->pParse = pParse
#define YYNSTATE 596
#define YYNRULE 311
#define YYFALLBACK 1
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
#define YY_ACTTAB_COUNT (1476)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   295,  568,  187,  432,  158,  569,  563,   50,   50,   50,
 /*    10 */    50,   43,   48,   48,   48,   48,   47,   47,   46,   46,
 /*    20 */    46,   45,  222,   47,   47,   46,   46,   46,   45,  222,
 /*    30 */   556,  550,   50,   50,   50,   50,  566,   48,   48,   48,
 /*    40 */    48,   47,   47,   46,   46,   46,   45,  222,  186,  133,
 /*    50 */   238,  433,   51,   52,   42,  548,  547,  549,  549,   49,
 /*    60 */    49,   50,   50,   50,   50,  593,   48,   48,   48,   48,
 /*    70 */    47,   47,   46,   46,   46,   45,  222,  295,  563,  482,
 /*    80 */   481,  386,   27,   48,   48,   48,   48,   47,   47,   46,
 /*    90 */    46,   46,   45,  222,   55,  532,  389,  236,  589,  588,
 /*   100 */   243,  327,  242,  450,  476,  567,   83,  556,  550,  284,
 /*   110 */   451,  224,  152,  574,   53,  357,  354,  353,   46,   46,
 /*   120 */    46,   45,  222,  492,  295,  498,  352,  561,  122,   51,
 /*   130 */    52,   42,  548,  547,  549,  549,   49,   49,   50,   50,
 /*   140 */    50,   50,  532,   48,   48,   48,   48,   47,   47,   46,
 /*   150 */    46,   46,   45,  222,  556,  550,  275,  457,  559,  559,
 /*   160 */   559,  224,  181,  180,    6,  282,  289,  398,  447,   59,
 /*   170 */   492,  295,  587,  328,  561,  237,   51,   52,   42,  548,
 /*   180 */   547,  549,  549,   49,   49,   50,   50,   50,   50,  201,
 /*   190 */    48,   48,   48,   48,   47,   47,   46,   46,   46,   45,
 /*   200 */   222,  556,  550,  433,  312,  559,  559,  559,  472,  473,
 /*   210 */   395,  898,  543,  898,   57,  396,  395,  897,  384,  897,
 /*   220 */   545,  545,    7,   51,   52,   42,  548,  547,  549,  549,
 /*   230 */    49,   49,   50,   50,   50,   50,  318,   48,   48,   48,
 /*   240 */    48,   47,   47,   46,   46,   46,   45,  222,  295,  527,
 /*   250 */   312,  386,  243,  327,  242,  224,  158,  457,  563,  399,
 /*   260 */   508,  191,  157,  224,  526,  399,  389,  319,  573,   59,
 /*   270 */   154,  265,  587,  589,  588,  567,   65,  563,  556,  550,
 /*   280 */   210,  525,  264,  486,  163,  128,  266,  360,  261,  359,
 /*   290 */   155,   33,  179,  448,    1,  566,  485,  257,  589,  588,
 /*   300 */    51,   52,   42,  548,  547,  549,  549,   49,   49,   50,
 /*   310 */    50,   50,   50,  634,   48,   48,   48,   48,   47,   47,
 /*   320 */    46,   46,   46,   45,  222,  295,  210,  299,  497,  182,
 /*   330 */   563,  128,  266,  360,  261,  359,  155,   60,   16,  386,
 /*   340 */   174,  589,  588,  257,  471,  586,  585,  152,  635,  563,
 /*   350 */   357,  354,  353,  636,  389,  556,  550,  185,  184,  183,
 /*   360 */   358,  352,  544,  567,   84,  252,  289,  397,   30,  470,
 /*   370 */   586,  585,  295,  546,  466,  494,  153,   51,   52,   42,
 /*   380 */   548,  547,  549,  549,   49,   49,   50,   50,   50,   50,
 /*   390 */   162,   48,   48,   48,   48,   47,   47,   46,   46,   46,
 /*   400 */    45,  222,  556,  550,  152,  373,  161,  357,  354,  353,
 /*   410 */   363,  531,  250,  586,  585,  396,  517,   39,  352,  295,
 /*   420 */   310,  255,  477,  153,   51,   52,   42,  548,  547,  549,
 /*   430 */   549,   49,   49,   50,   50,   50,   50,  386,   48,   48,
 /*   440 */    48,   48,   47,   47,   46,   46,   46,   45,  222,  556,
 /*   450 */   550,  350,  389,  153,  437,  384,  153,  545,  545,  510,
 /*   460 */   294,  567,   77,  534,  458,  200,  295,  542,  170,  254,
 /*   470 */   533,   51,   52,   42,  548,  547,  549,  549,   49,   49,
 /*   480 */    50,   50,   50,   50,  386,   48,   48,   48,   48,   47,
 /*   490 */    47,   46,   46,   46,   45,  222,  556,  550,  501,  389,
 /*   500 */   175,  371,  217,  426,  384,  157,  545,  545,  567,   77,
 /*   510 */   441,  441,  343,  295,  177,   44,   41,  136,   51,   52,
 /*   520 */    42,  548,  547,  549,  549,   49,   49,   50,   50,   50,
 /*   530 */    50,  386,   48,   48,   48,   48,   47,   47,   46,   46,
 /*   540 */    46,   45,  222,  556,  550,  384,  389,  545,  545,  218,
 /*   550 */   908,  173,  394,    2,  530,  567,   84,  584,  583,  582,
 /*   560 */   295,  384,  529,  545,  545,   51,   52,   42,  548,  547,
 /*   570 */   549,  549,   49,   49,   50,   50,   50,   50,  409,   48,
 /*   580 */    48,   48,   48,   47,   47,   46,   46,   46,   45,  222,
 /*   590 */   556,  550,  188,  587,  314,  541,  540,  369,  410,  411,
 /*   600 */    44,   41,  136,  534,  381,  200,  425,  295,   18,  414,
 /*   610 */   160,   18,   51,   40,   42,  548,  547,  549,  549,   49,
 /*   620 */    49,   50,   50,   50,   50,  409,   48,   48,   48,   48,
 /*   630 */    47,   47,   46,   46,   46,   45,  222,  556,  550,  401,
 /*   640 */   587,  291,  382,  541,  540,  410,  316,  538,  538,   34,
 /*   650 */   528,   32,  524,  439,  295,   29,  221,  440,  412,  221,
 /*   660 */    52,   42,  548,  547,  549,  549,   49,   49,   50,   50,
 /*   670 */    50,   50,  341,   48,   48,   48,   48,   47,   47,   46,
 /*   680 */    46,   46,   45,  222,  556,  550,  393,  592,  365,  589,
 /*   690 */   588,  515,  225,  571,  121,  366,  589,  588,  572,  459,
 /*   700 */   193,  462,  589,  588,  221,  317,  221,  462,   42,  548,
 /*   710 */   547,  549,  549,   49,   49,   50,   50,   50,   50,  144,
 /*   720 */    48,   48,   48,   48,   47,   47,   46,   46,   46,   45,
 /*   730 */   222,   38,  380,    3,  566,  333,  520,  390,  588,  325,
 /*   740 */   258,    4,  334,  589,  588,  519,  589,  588,  383,   13,
 /*   750 */    38,  380,    3,  536,  220,  587,  390,  588,  320,  555,
 /*   760 */   554,  586,  585,  362,  406,  135,   12,  383,  586,  585,
 /*   770 */   378,  408,  386,  407,  586,  585,  436,  309,  169,   58,
 /*   780 */   515,  532,  315,  563,  552,  551,  490,  389,  568,  378,
 /*   790 */   515,  527,  569,  512,  514,  570,  567,   69,  306,  195,
 /*   800 */   532,   35,   36,  500,  199,  133,  526,  153,   37,  388,
 /*   810 */   387,  553,  499,  561,  836,  586,  585,  195,  586,  585,
 /*   820 */    35,   36,  156,  525,   25,  377,  120,   37,  388,  387,
 /*   830 */   349,  202,  561,  566,  595,    2,  287,  286,  285,  165,
 /*   840 */   283,  513,  303,  421,  559,  559,  559,  558,  557,   14,
 /*   850 */   224,  566,  496,  223,  135,  563,  139,  329,  504,  506,
 /*   860 */    17,  154,  132,  559,  559,  559,  558,  557,   14,  300,
 /*   870 */   137,  340,  495,   56,  587,  329,  337,  386,  326,  515,
 /*   880 */    38,  380,    3,  141,  131,  433,  390,  588,  258,  479,
 /*   890 */   596,  594,  389,  140,  510,  248,  336,  383,   28,  380,
 /*   900 */     3,  567,   69,  587,  390,  588,  258,  400,  290,  215,
 /*   910 */   587,  335,  330,  335,  469,  383,  256,  386,  299,  378,
 /*   920 */    23,  587,  313,  257,  258,  209,  587,  587,  587,  386,
 /*   930 */   532,  386,  389,  216,  243,  322,  232,  378,  247,  587,
 /*   940 */   298,  567,   64,  308,  389,  224,  389,  302,  532,  386,
 /*   950 */    35,   36,  258,  567,   61,  567,   86,   37,  388,  387,
 /*   960 */   356,  307,  561,  506,  389,  189,  386,  587,   35,   36,
 /*   970 */    45,  222,  335,  567,   89,   37,  388,  387,  587,  207,
 /*   980 */   561,  389,  536,  220,  198,  386,  118,  587,  351,  305,
 /*   990 */   567,   87,  506,  559,  559,  559,  558,  557,   14,  566,
 /*  1000 */   389,  208,  117,  241,  330,  386,  510,  587,   22,  567,
 /*  1010 */    96,  559,  559,  559,  558,  557,   14,  386,  566,  587,
 /*  1020 */   389,  116,  386,  194,  386,  248,  342,  190,  386,  567,
 /*  1030 */    95,  510,  389,  488,  487,  386,  151,  389,  264,  389,
 /*  1040 */   587,  567,   84,  389,  347,  270,  567,   98,  567,   99,
 /*  1050 */   389,  386,  567,  123,  386,  304,  192,  566,  445,  567,
 /*  1060 */   124,  566,  206,  435,  487,  114,  389,  386,  420,  389,
 /*  1070 */   268,  203,  386,  344,  590,  567,   90,  442,  567,   94,
 /*  1080 */   386,  157,  389,  373,  386,  113,  386,  389,  374,  587,
 /*  1090 */   566,  567,   93,  245,  438,  389,  567,   85,  386,  389,
 /*  1100 */   386,  389,  386,  112,  567,   92,  386,  146,  567,   68,
 /*  1110 */   567,   88,  147,  389,   15,  389,  431,  389,  386,  428,
 /*  1120 */   110,  389,  567,  127,  567,  126,  567,  125,  109,  386,
 /*  1130 */   567,   67,   20,  389,  386,  145,  578,   19,   11,  423,
 /*  1140 */   386,  577,  567,   82,  389,  386,  107,  386,  101,  389,
 /*  1150 */   419,  587,  576,  567,   81,  389,  587,  103,  567,   66,
 /*  1160 */   389,  386,  389,  386,  567,   80,  386,  587,  129,  567,
 /*  1170 */    79,  567,   91,  143,  248,  142,  389,  386,  389,  386,
 /*  1180 */   100,  389,   10,  587,  386,  567,   78,  567,   76,  587,
 /*  1190 */   567,   75,  389,  413,  389,  386,  248,  386,  385,  389,
 /*  1200 */   386,  567,   74,  567,   63,  405,  404,  176,  567,   62,
 /*  1210 */   389,  587,  389,  587,  138,  389,  386,  418,  364,  567,
 /*  1220 */    73,  567,   72,  560,  567,   71,   97,  297,  296,  248,
 /*  1230 */   591,  389,  248,  389,  167,  248,  375,  523,  587,  417,
 /*  1240 */   567,   70,  567,    9,  587,  511,  507,  587,  505,  260,
 /*  1250 */   587,  587,  587,  475,  259,  455,  214,  115,  253,  251,
 /*  1260 */   587,  587,  249,  587,  587,  166,  244,  338,  587,  587,
 /*  1270 */   587,  430,  205,  587,  587,  204,  429,  587,  229,  331,
 /*  1280 */   239,  587,  587,  422,  579,  228,  587,  581,  164,  227,
 /*  1290 */   226,  587,  274,  134,  587,  587,  368,  580,  587,  392,
 /*  1300 */   587,  273,    8,  391,  587,  587,  224,  587,  587,  565,
 /*  1310 */   279,  587,   31,  372,   25,  370,  587,   26,  219,  278,
 /*  1320 */    54,  277,  522,  159,  276,  171,  564,   24,  367,  489,
 /*  1330 */   361,  484,  311,  483,  271,  262,  509,  269,  480,  503,
 /*  1340 */   479,  119,  267,  478,  212,  502,  454,  460,  293,  453,
 /*  1350 */   452,  292,  150,  348,  446,  149,  345,  197,  444,   21,
 /*  1360 */   148,  130,  108,  339,  324,  434,  111,  323,  233,  301,
 /*  1370 */   213,  106,  105,  172,  211,  104,  168,  424,  288,  562,
 /*  1380 */   234,  102,  403,  402,  246,  416,  575,  521,  539,  464,
 /*  1390 */   443,  379,  518,  537,  178,  263,  230,  465,  415,  476,
 /*  1400 */   280,  222,  461,  535,  463,  594,  355,  909,  427,  909,
 /*  1410 */   909,  909,  332,  909,  909,  909,  493,  272,  231,  909,
 /*  1420 */   491,  909,  909,  235,  474,  321,  468,    5,  467,  281,
 /*  1430 */   456,  376,  909,  449,  909,  909,  909,  909,  909,  909,
 /*  1440 */   516,  909,  909,  909,  909,  909,  909,  909,  909,  909,
 /*  1450 */   909,  909,  240,  909,  909,  909,  909,  909,  909,  909,
 /*  1460 */   909,  909,  909,  909,  909,  909,  909,  909,  909,  909,
 /*  1470 */   909,  909,  909,  196,  909,  346,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    16,  113,  158,    8,   20,  117,   22,   77,   78,   79,
 /*    10 */    80,   81,   82,   83,   84,   85,   86,   87,   88,   89,
 /*    20 */    90,   91,   92,   86,   87,   88,   89,   90,   91,   92,
 /*    30 */    46,   47,   77,   78,   79,   80,  192,   82,   83,   84,
 /*    40 */    85,   86,   87,   88,   89,   90,   91,   92,  204,  205,
 /*    50 */    13,   56,   68,   69,   70,   71,   72,   73,   74,   75,
 /*    60 */    76,   77,   78,   79,   80,    1,   82,   83,   84,   85,
 /*    70 */    86,   87,   88,   89,   90,   91,   92,   16,   94,    4,
 /*    80 */     5,  148,   21,   82,   83,   84,   85,   86,   87,   88,
 /*    90 */    89,   90,   91,   92,   18,   66,  163,   60,   22,   23,
 /*   100 */   105,  106,  107,  179,  180,  172,  173,   46,   47,   12,
 /*   110 */   186,  116,   96,   19,   53,   99,  100,  101,   88,   89,
 /*   120 */    90,   91,   92,   94,   16,   19,  110,   98,   20,   68,
 /*   130 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*   140 */    79,   80,   66,   82,   83,   84,   85,   86,   87,   88,
 /*   150 */    89,   90,   91,   92,   46,   47,  223,  148,  129,  130,
 /*   160 */   131,  116,   86,   87,   18,  156,   18,   19,  159,  160,
 /*   170 */    94,   16,  163,  128,   98,  138,   68,   69,   70,   71,
 /*   180 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   18,
 /*   190 */    82,   83,   84,   85,   86,   87,   88,   89,   90,   91,
 /*   200 */    92,   46,   47,   56,   16,  129,  130,  131,   97,   98,
 /*   210 */    18,   19,   19,   21,   21,   67,   18,   19,  112,   21,
 /*   220 */   114,  115,   76,   68,   69,   70,   71,   72,   73,   74,
 /*   230 */    75,   76,   77,   78,   79,   80,   97,   82,   83,   84,
 /*   240 */    85,   86,   87,   88,   89,   90,   91,   92,   16,    9,
 /*   250 */    16,  148,  105,  106,  107,  116,   20,  148,   22,   67,
 /*   260 */    19,  158,   21,  116,   24,   67,  163,  128,  159,  160,
 /*   270 */    47,   98,  163,   22,   23,  172,  173,   22,   46,   47,
 /*   280 */    92,   41,  109,   43,   96,   97,   98,   99,  100,  101,
 /*   290 */   102,  136,  183,  184,   18,  192,   56,  109,   22,   23,
 /*   300 */    68,   69,   70,   71,   72,   73,   74,   75,   76,   77,
 /*   310 */    78,   79,   80,  118,   82,   83,   84,   85,   86,   87,
 /*   320 */    88,   89,   90,   91,   92,   16,   92,  104,   19,   21,
 /*   330 */    94,   97,   98,   99,  100,  101,  102,   18,   18,  148,
 /*   340 */    20,   22,   23,  109,   32,   94,   95,   96,  118,   94,
 /*   350 */    99,  100,  101,  118,  163,   46,   47,  105,  106,  107,
 /*   360 */    48,  110,   19,  172,  173,   13,   18,   19,  136,   57,
 /*   370 */    94,   95,   16,  113,   19,   19,   21,   68,   69,   70,
 /*   380 */    71,   72,   73,   74,   75,   76,   77,   78,   79,   80,
 /*   390 */   118,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*   400 */    91,   92,   46,   47,   96,  214,  118,   99,  100,  101,
 /*   410 */   219,   19,   60,   94,   95,   67,   21,   18,  110,   16,
 /*   420 */   108,   19,   19,   21,   68,   69,   70,   71,   72,   73,
 /*   430 */    74,   75,   76,   77,   78,   79,   80,  148,   82,   83,
 /*   440 */    84,   85,   86,   87,   88,   89,   90,   91,   92,   46,
 /*   450 */    47,   19,  163,   21,   19,  112,   21,  114,  115,  164,
 /*   460 */   161,  172,  173,  164,  165,  166,   16,   19,   19,   19,
 /*   470 */    19,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   480 */    77,   78,   79,   80,  148,   82,   83,   84,   85,   86,
 /*   490 */    87,   88,   89,   90,   91,   92,   46,   47,  203,  163,
 /*   500 */    18,  212,  213,   19,  112,   21,  114,  115,  172,  173,
 /*   510 */   105,  106,  107,   16,  119,  220,  221,  222,   68,   69,
 /*   520 */    70,   71,   72,   73,   74,   75,   76,   77,   78,   79,
 /*   530 */    80,  148,   82,   83,   84,   85,   86,   87,   88,   89,
 /*   540 */    90,   91,   92,   46,   47,  112,  163,  114,  115,  213,
 /*   550 */   140,  141,  142,  143,    8,  172,  173,    4,    5,    6,
 /*   560 */    16,  112,   19,  114,  115,   68,   69,   70,   71,   72,
 /*   570 */    73,   74,   75,   76,   77,   78,   79,   80,  148,   82,
 /*   580 */    83,   84,   85,   86,   87,   88,   89,   90,   91,   92,
 /*   590 */    46,   47,   18,  163,  167,  168,  169,  214,  168,  169,
 /*   600 */   220,  221,  222,  164,  165,  166,   19,   16,   21,   19,
 /*   610 */    21,   21,   68,   69,   70,   71,   72,   73,   74,   75,
 /*   620 */    76,   77,   78,   79,   80,  148,   82,   83,   84,   85,
 /*   630 */    86,   87,   88,   89,   90,   91,   92,   46,   47,   19,
 /*   640 */   163,   21,  167,  168,  169,  168,  169,  129,  130,  135,
 /*   650 */    19,  137,   19,   26,   16,   21,  229,   30,  228,  229,
 /*   660 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*   670 */    79,   80,   45,   82,   83,   84,   85,   86,   87,   88,
 /*   680 */    89,   90,   91,   92,   46,   47,  144,  145,   16,   22,
 /*   690 */    23,   21,  150,  171,  152,   23,   22,   23,  170,  171,
 /*   700 */   158,  179,   22,   23,  229,  228,  229,  179,   70,   71,
 /*   710 */    72,   73,   74,   75,   76,   77,   78,   79,   80,   21,
 /*   720 */    82,   83,   84,   85,   86,   87,   88,   89,   90,   91,
 /*   730 */    92,   16,   17,   18,  192,   16,   28,   22,   23,   63,
 /*   740 */   148,   31,   23,   22,   23,   37,   22,   23,   33,   21,
 /*   750 */    16,   17,   18,   86,   87,  163,   22,   23,  216,   46,
 /*   760 */    47,   94,   95,   88,   97,   95,   31,   33,   94,   95,
 /*   770 */    55,  104,  148,  106,   94,   95,  100,  185,   19,   18,
 /*   780 */    21,   66,  240,   22,   71,   72,  163,  163,  113,   55,
 /*   790 */   120,    9,  117,  120,  120,  172,  172,  173,  153,  158,
 /*   800 */    66,   86,   87,   88,  204,  205,   24,   21,   93,   94,
 /*   810 */    95,   98,   88,   98,  138,   94,   95,  158,   94,   95,
 /*   820 */    86,   87,   31,   41,  126,   43,   18,   93,   94,   95,
 /*   830 */    16,    2,   98,  192,  142,  143,    7,    8,    9,   10,
 /*   840 */    11,  120,  218,   14,  129,  130,  131,  132,  133,  134,
 /*   850 */   116,  192,   19,  195,   95,   94,   27,  216,   23,  148,
 /*   860 */   202,   47,  118,  129,  130,  131,  132,  133,  134,  241,
 /*   870 */   242,  226,   19,  232,  163,  216,  231,  148,  237,  120,
 /*   880 */    16,   17,   18,   54,   35,   56,   22,   23,  148,  103,
 /*   890 */     0,    1,  163,   64,  164,  148,  237,   33,   16,   17,
 /*   900 */    18,  172,  173,  163,   22,   23,  148,  243,  244,   51,
 /*   910 */   163,  148,  148,  148,   25,   33,   19,  148,  104,   55,
 /*   920 */    18,  163,  211,  109,  148,  185,  163,  163,  163,  148,
 /*   930 */    66,  148,  163,  203,  105,  106,  107,   55,  191,  163,
 /*   940 */   111,  172,  173,  185,  163,  116,  163,  218,   66,  148,
 /*   950 */    86,   87,  148,  172,  173,  172,  173,   93,   94,   95,
 /*   960 */    51,  185,   98,  148,  163,  158,  148,  163,   86,   87,
 /*   970 */    91,   92,  148,  172,  173,   93,   94,   95,  163,  215,
 /*   980 */    98,  163,   86,   87,  158,  148,   18,  163,   51,  185,
 /*   990 */   172,  173,  148,  129,  130,  131,  132,  133,  134,  192,
 /*  1000 */   163,  238,   18,  238,  148,  148,  164,  163,   18,  172,
 /*  1010 */   173,  129,  130,  131,  132,  133,  134,  148,  192,  163,
 /*  1020 */   163,   18,  148,  158,  148,  148,  211,  158,  148,  172,
 /*  1030 */   173,  164,  163,  188,  189,  148,  102,  163,  109,  163,
 /*  1040 */   163,  172,  173,  163,   16,  203,  172,  173,  172,  173,
 /*  1050 */   163,  148,  172,  173,  148,  211,  158,  192,   17,  172,
 /*  1060 */   173,  192,  238,  188,  189,  104,  163,  148,  191,  163,
 /*  1070 */   203,  215,  148,   39,  148,  172,  173,   58,  172,  173,
 /*  1080 */   148,   21,  163,  214,  148,   52,  148,  163,  219,  163,
 /*  1090 */   192,  172,  173,  138,   52,  163,  172,  173,  148,  163,
 /*  1100 */   148,  163,  148,   18,  172,  173,  148,  118,  172,  173,
 /*  1110 */   172,  173,  104,  163,    2,  163,    1,  163,  148,   23,
 /*  1120 */   108,  163,  172,  173,  172,  173,  172,  173,  127,  148,
 /*  1130 */   172,  173,   76,  163,  148,   31,  148,   76,   18,    1,
 /*  1140 */   148,  148,  172,  173,  163,  148,  119,  148,  108,  163,
 /*  1150 */    17,  163,  148,  172,  173,  163,  163,  119,  172,  173,
 /*  1160 */   163,  148,  163,  148,  172,  173,  148,  163,  148,  172,
 /*  1170 */   173,  172,  173,   13,  148,  121,  163,  148,  163,  148,
 /*  1180 */   127,  163,   18,  163,  148,  172,  173,  172,  173,  163,
 /*  1190 */   172,  173,  163,  128,  163,  148,  148,  148,  148,  163,
 /*  1200 */   148,  172,  173,  172,  173,   19,   19,   18,  172,  173,
 /*  1210 */   163,  163,  163,  163,  242,  163,  148,  191,  148,  172,
 /*  1220 */   173,  172,  173,  148,  172,  173,  162,  245,  245,  148,
 /*  1230 */   147,  163,  148,  163,    3,  148,  148,  148,  163,  191,
 /*  1240 */   172,  173,  172,  173,  163,  148,  148,  163,  148,  148,
 /*  1250 */   163,  163,  163,  148,  148,  148,  178,  178,  148,  148,
 /*  1260 */   163,  163,  148,  163,  163,  149,  148,  148,  163,  163,
 /*  1270 */   163,  148,  191,  163,  163,  191,  148,  163,  191,  148,
 /*  1280 */   148,  163,  163,  148,   10,  148,  163,  147,  149,  148,
 /*  1290 */   148,  163,  148,  148,  163,  163,  148,  147,  163,  147,
 /*  1300 */   163,  148,   21,  157,  163,  163,  116,  163,  163,  192,
 /*  1310 */   197,  163,  135,  122,  126,  123,  163,  124,  224,  198,
 /*  1320 */   125,  199,  155,  118,  200,  155,  201,  104,  121,  174,
 /*  1330 */   104,  174,   44,  182,  208,  174,  209,  208,  176,  209,
 /*  1340 */   103,   18,  208,  174,   92,  209,  174,  182,  177,  174,
 /*  1350 */   174,  177,  154,   15,  155,  154,   42,  155,  155,  135,
 /*  1360 */   154,   68,   18,  155,  155,  187,  187,   15,  200,  155,
 /*  1370 */   227,  190,  190,  217,  227,  190,  217,  197,  146,  164,
 /*  1380 */   197,  187,  155,  155,  235,  201,  151,  175,  230,  164,
 /*  1390 */   236,  225,  175,  230,  194,  175,  200,  175,  201,  180,
 /*  1400 */   196,   92,  164,  164,  175,    1,  176,  246,  197,  246,
 /*  1410 */   246,  246,  239,  246,  246,  246,  172,  207,  197,  246,
 /*  1420 */   172,  246,  246,  207,  181,  207,  181,  194,  181,  193,
 /*  1430 */   184,  189,  246,  184,  246,  246,  246,  246,  246,  246,
 /*  1440 */   206,  246,  246,  246,  246,  246,  246,  246,  246,  246,
 /*  1450 */   246,  246,  239,  246,  246,  246,  246,  246,  246,  246,
 /*  1460 */   246,  246,  246,  246,  246,  246,  246,  246,  246,  246,
 /*  1470 */   246,  246,  246,  233,  246,  234,
};
#define YY_SHIFT_USE_DFLT (-113)
#define YY_SHIFT_COUNT (393)
#define YY_SHIFT_MIN   (-112)
#define YY_SHIFT_MAX   (1404)
static const short yy_shift_ofst[] = {
 /*     0 */  1404,  734,  829,  734,  864,  864,  667,  667,  251,  -16,
 /*    10 */   864,  864,  864,  864,  864,  147,  680,  715,  864,  864,
 /*    20 */   864,  864,  864,  864,  864,  864,  864,  864,  864,  864,
 /*    30 */   864,  864,  864,  864,  864,  864,  864,  864,  864,  864,
 /*    40 */   864,  864,  882,  864,  864,  864,  864,  864,  864,  864,
 /*    50 */   864,  864,  864,  864,  864,  864,   -5,  896,  896,  255,
 /*    60 */  1190,   61,  450,  403,  356,  309,  232,  155,  108,  497,
 /*    70 */   497,  497,  497,  497,  497,  497,  497,  497,  497,  497,
 /*    80 */   497,  497,  497,  497,  497,  544,  497,  591,  638,  638,
 /*    90 */   -70,  -45,  -45,  -45,  -45,  -45,    1,  188,  -63,   30,
 /*   100 */   680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
 /*   110 */   680,  680,  680,  680,  680,  814,  680,  680,  680,  680,
 /*   120 */   680,  676,  255,  879, 1309, -113, -113, -113,   76,  234,
 /*   130 */   240,  240,  724,  319,  721,  674,  276,  198,  192,  680,
 /*   140 */   680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
 /*   150 */   680,  680,  680,  680,  680,  680,  680,  680,  680,  680,
 /*   160 */   680,  680,  680,  680,  680,  680,  680,  680,  139,  236,
 /*   170 */   236,  236,   45,  890, 1190, 1190, -113, -113, -113,  308,
 /*   180 */    29,   29,   16,  312,  312,  312,  759,  449,  782,  392,
 /*   190 */   343,  106,  433,  433,  433,  433,  405,  627,  433,  670,
 /*   200 */   761,  675,  553,  698,  672,  672,  719,  698,  719,  786,
 /*   210 */   255,  708,  255,  708,  223,  708,  672,  708,  708,  514,
 /*   220 */   518,  518,  255,  395, -112,  320, 1205, 1205, 1205, 1344,
 /*   230 */  1195, 1191, 1293, 1195, 1191, 1188, 1352, 1352, 1352, 1205,
 /*   240 */  1188, 1344, 1293, 1293, 1205, 1338, 1224, 1314, 1205, 1205,
 /*   250 */  1338, 1205, 1338, 1323, 1226, 1226, 1226, 1288, 1252, 1252,
 /*   260 */  1323, 1226, 1237, 1226, 1288, 1226, 1226, 1207, 1223, 1207,
 /*   270 */  1223, 1207, 1223, 1205, 1205, 1177, 1195, 1191, 1193, 1192,
 /*   280 */  1188, 1190, 1281, 1274, 1274, 1231, 1231, 1231, 1231, -113,
 /*   290 */  -113, -113, -113, -113, -113,  713,  348,  148,   37,  252,
 /*   300 */   620,  146,  590,  587,  484,  435,  352,  432,  402,  355,
 /*   310 */   111,   75,  173,  241,  193, 1189, 1187, 1186, 1065, 1164,
 /*   320 */  1053, 1040, 1038, 1133, 1054, 1160, 1138, 1027, 1120, 1001,
 /*   330 */  1061, 1056, 1012, 1096, 1104,  989, 1115, 1112, 1085, 1008,
 /*   340 */   955, 1042, 1060, 1033, 1019, 1034,  961, 1041, 1028,  929,
 /*   350 */   934, 1003,  937,  990,  984,  897,  968,  909,  889,  902,
 /*   360 */   858,  849,  853,  833,  744,  835,  791,  808,  673,  634,
 /*   370 */   735,  728,  710,  634,  633,  631,  589,  543,  574,  546,
 /*   380 */   482,  451,  448,  399,  260,  288,  272,  235,  230,  195,
 /*   390 */   171,   94,   97,   64,
};
#define YY_REDUCE_USE_DFLT (-157)
#define YY_REDUCE_COUNT (294)
#define YY_REDUCE_MIN   (-156)
#define YY_REDUCE_MAX   (1249)
static const short yy_reduce_ofst[] = {
 /*     0 */   410,  869,  542,  103,  289,  191,  477,  430,  109,  295,
 /*    10 */   729,  624,  383,  336,  -67,  641,    9, 1070, 1068, 1052,
 /*    20 */  1049, 1047, 1036, 1031, 1029, 1018, 1015, 1013,  999,  997,
 /*    30 */   992,  986,  981,  970,  958,  954,  952,  950,  938,  936,
 /*    40 */   932,  924,  919,  906,  903,  887,  880,  876,  874,  857,
 /*    50 */   837,  818,  801,  783,  781,  769,  659,  475,  427,  299,
 /*    60 */  -156,  380,  380,  380,  380,  380,  380,  380,  380,  380,
 /*    70 */   380,  380,  380,  380,  380,  380,  380,  380,  380,  380,
 /*    80 */   380,  380,  380,  380,  380,  380,  380,  380,  380,  380,
 /*    90 */   380,  380,  380,  380,  380,  380,  380,  528,  380,  380,
 /*   100 */  1087,  856, 1084, 1081, 1048, 1026,  877,  824,  844,  765,
 /*   110 */   764,  763,  804,  815,  747,  -76,  776,  758,  740,  592,
 /*   120 */   711,  645,  439,  380,  380,  380,  380,  380,  623,  522,
 /*   130 */   875,  845, 1050, 1153, 1148, 1145, 1144,  664,  664, 1142,
 /*   140 */  1141, 1137, 1135, 1132, 1131, 1128, 1123, 1119, 1118, 1114,
 /*   150 */  1111, 1110, 1107, 1106, 1105, 1101, 1100, 1098, 1097, 1089,
 /*   160 */  1088, 1075, 1050, 1020, 1004,  993,  988,  926,  898,  867,
 /*   170 */   842,  730,  865,  692,  826,  807,  628,  600,  658, 1249,
 /*   180 */  1248, 1244, 1246, 1247, 1245, 1243, 1234, 1236, 1242, 1236,
 /*   190 */  1236, 1236, 1236, 1236, 1236, 1236, 1241, 1240, 1236, 1234,
 /*   200 */  1239, 1233, 1232, 1221, 1218, 1216, 1213, 1211, 1173, 1230,
 /*   210 */  1238, 1229, 1225, 1222, 1219, 1220, 1210, 1217, 1212, 1166,
 /*   220 */  1163, 1158, 1215, 1204, 1200, 1235, 1228, 1227, 1214, 1159,
 /*   230 */  1197, 1196, 1194, 1184, 1168, 1183, 1185, 1182, 1181, 1209,
 /*   240 */  1180, 1156, 1179, 1178, 1208, 1206, 1154, 1149, 1203, 1202,
 /*   250 */  1201, 1199, 1198, 1174, 1176, 1175, 1172, 1165, 1147, 1143,
 /*   260 */  1171, 1169, 1162, 1161, 1151, 1157, 1155, 1136, 1134, 1130,
 /*   270 */  1129, 1127, 1126, 1170, 1167, 1094, 1125, 1124, 1122, 1121,
 /*   280 */  1113, 1117, 1146, 1139, 1116, 1152, 1150, 1140, 1083,  983,
 /*   290 */   982,  972, 1079, 1078, 1064,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   601,  831,  907,  907,  907,  831,  858,  858,  907,  720,
 /*    10 */   907,  907,  907,  907,  829,  907,  907,  907,  907,  907,
 /*    20 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*    30 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*    40 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*    50 */   907,  907,  907,  907,  907,  907,  907,  858,  858,  637,
 /*    60 */   724,  755,  907,  907,  907,  907,  907,  907,  907,  770,
 /*    70 */   769,  763,  762,  871,  735,  760,  753,  746,  757,  832,
 /*    80 */   825,  826,  824,  828,  833,  907,  756,  792,  809,  791,
 /*    90 */   803,  808,  815,  807,  804,  794,  793,  629,  795,  796,
 /*   100 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   110 */   907,  907,  907,  907,  907,  691,  907,  907,  907,  907,
 /*   120 */   907,  624,  907,  797,  798,  812,  811,  810,  907,  907,
 /*   130 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  892,
 /*   140 */   890,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   150 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   160 */   907,  907,  907,  907,  907,  907,  907,  605,  907,  720,
 /*   170 */   720,  720,  907,  601,  907,  907,  899,  724,  714,  682,
 /*   180 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   190 */   907,  907,  765,  703,  881,  883,  907,  864,  626,  722,
 /*   200 */   639,  712,  607,  759,  737,  737,  876,  759,  876,  663,
 /*   210 */   907,  749,  907,  749,  660,  749,  737,  749,  749,  827,
 /*   220 */   907,  907,  907,  721,  712,  907,  728,  728,  728,  771,
 /*   230 */   754,  742,  695,  754,  742,  759,  702,  702,  702,  728,
 /*   240 */   759,  771,  695,  695,  728,  622,  870,  868,  728,  728,
 /*   250 */   622,  728,  622,  837,  693,  693,  693,  678,  841,  841,
 /*   260 */   837,  693,  663,  693,  678,  693,  693,  741,  736,  741,
 /*   270 */   736,  741,  736,  728,  728,  907,  754,  742,  752,  750,
 /*   280 */   759,  907,  681,  615,  615,  604,  604,  604,  604,  904,
 /*   290 */   904,  899,  665,  665,  647,  907,  907,  907,  907,  907,
 /*   300 */   907,  844,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   310 */   907,  907,  907,  907,  907,  894,  907,  907,  907,  907,
 /*   320 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   330 */   907,  907,  907,  907,  907,  874,  907,  907,  907,  907,
 /*   340 */   907,  907,  867,  866,  907,  907,  907,  907,  907,  907,
 /*   350 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  907,
 /*   360 */   907,  907,  907,  907,  907,  907,  907,  907,  907,  751,
 /*   370 */   907,  743,  907,  830,  907,  907,  907,  907,  907,  907,
 /*   380 */   907,  907,  907,  907,  706,  780,  907,  779,  783,  778,
 /*   390 */   631,  907,  613,  907,  598,  903,  906,  905,  902,  901,
 /*   400 */   900,  895,  893,  891,  848,  846,  853,  852,  851,  850,
 /*   410 */   849,  847,  845,  766,  764,  761,  758,  889,  843,  701,
 /*   420 */   700,  621,  896,  873,  882,  880,  772,  879,  878,  877,
 /*   430 */   875,  872,  859,  768,  767,  696,  835,  834,  863,  862,
 /*   440 */   861,  865,  869,  860,  730,  623,  620,  628,  685,  684,
 /*   450 */   692,  690,  689,  688,  687,  686,  683,  630,  638,  649,
 /*   460 */   677,  662,  661,  840,  842,  839,  838,  670,  669,  675,
 /*   470 */   674,  673,  672,  671,  668,  667,  666,  659,  658,  664,
 /*   480 */   657,  680,  679,  676,  656,  699,  698,  697,  694,  655,
 /*   490 */   654,  653,  783,  652,  651,  789,  788,  776,  819,  717,
 /*   500 */   716,  715,  727,  726,  739,  738,  774,  773,  740,  725,
 /*   510 */   719,  718,  734,  733,  732,  731,  723,  713,  745,  748,
 /*   520 */   747,  744,  821,  729,  818,  888,  887,  886,  885,  884,
 /*   530 */   823,  822,  790,  787,  642,  643,  857,  855,  856,  854,
 /*   540 */   645,  644,  641,  640,  820,  708,  707,  816,  813,  805,
 /*   550 */   801,  817,  814,  806,  802,  800,  799,  785,  784,  782,
 /*   560 */   781,  777,  786,  633,  709,  705,  704,  775,  711,  710,
 /*   570 */   650,  648,  646,  627,  625,  619,  617,  616,  618,  614,
 /*   580 */   612,  611,  610,  609,  608,  636,  635,  634,  632,  631,
 /*   590 */   606,  603,  602,  600,  599,  597,
};

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
   22,  /*      BEGIN => ID */
    0,  /* TRANSACTION => nothing */
   22,  /*   DEFERRED => ID */
   22,  /*  IMMEDIATE => ID */
   22,  /*  EXCLUSIVE => ID */
    0,  /*     COMMIT => nothing */
   22,  /*        END => ID */
   22,  /*   ROLLBACK => ID */
   22,  /*  SAVEPOINT => ID */
   22,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   22,  /*         IF => ID */
    0,  /*        NOT => nothing */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*         AS => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   22,  /*      ABORT => ID */
   22,  /*     ACTION => ID */
   22,  /*      AFTER => ID */
   22,  /*    ANALYZE => ID */
   22,  /*        ASC => ID */
   22,  /*     ATTACH => ID */
   22,  /*     BEFORE => ID */
   22,  /*         BY => ID */
   22,  /*    CASCADE => ID */
   22,  /*       CAST => ID */
   22,  /*   COLUMNKW => ID */
   22,  /*   CONFLICT => ID */
   22,  /*   DATABASE => ID */
   22,  /*       DESC => ID */
   22,  /*     DETACH => ID */
   22,  /*       EACH => ID */
   22,  /*    EXPLAIN => ID */
   22,  /*       FAIL => ID */
   22,  /*        FOR => ID */
   22,  /*     IGNORE => ID */
   22,  /*  INITIALLY => ID */
   22,  /*    INSTEAD => ID */
   22,  /*    LIKE_KW => ID */
   22,  /*      MATCH => ID */
   22,  /*         NO => ID */
   22,  /*       PLAN => ID */
   22,  /*      QUERY => ID */
   22,  /*        KEY => ID */
   22,  /*         OF => ID */
   22,  /*     OFFSET => ID */
   22,  /*     PRAGMA => ID */
   22,  /*      RAISE => ID */
   22,  /*    REPLACE => ID */
   22,  /*   RESTRICT => ID */
   22,  /*        ROW => ID */
   22,  /*       TEMP => ID */
   22,  /*    TRIGGER => ID */
   22,  /*     VACUUM => ID */
   22,  /*       VIEW => ID */
   22,  /*    VIRTUAL => ID */
   22,  /*    REINDEX => ID */
   22,  /*     RENAME => ID */
   22,  /*   CTIME_KW => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  sqlite3ParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3ParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "BEGIN",         "TRANSACTION", 
  "DEFERRED",      "IMMEDIATE",     "EXCLUSIVE",     "COMMIT",      
  "END",           "ROLLBACK",      "SAVEPOINT",     "RELEASE",     
  "TO",            "TABLE",         "CREATE",        "IF",          
  "NOT",           "EXISTS",        "LP",            "RP",          
  "AS",            "COMMA",         "ID",            "INDEXED",     
  "ABORT",         "ACTION",        "AFTER",         "ANALYZE",     
  "ASC",           "ATTACH",        "BEFORE",        "BY",          
  "CASCADE",       "CAST",          "COLUMNKW",      "CONFLICT",    
  "DATABASE",      "DESC",          "DETACH",        "EACH",        
  "EXPLAIN",       "FAIL",          "FOR",           "IGNORE",      
  "INITIALLY",     "INSTEAD",       "LIKE_KW",       "MATCH",       
  "NO",            "PLAN",          "QUERY",         "KEY",         
  "OF",            "OFFSET",        "PRAGMA",        "RAISE",       
  "REPLACE",       "RESTRICT",      "ROW",           "TEMP",        
  "TRIGGER",       "VACUUM",        "VIEW",          "VIRTUAL",     
  "REINDEX",       "RENAME",        "CTIME_KW",      "ANY",         
  "OR",            "AND",           "IS",            "BETWEEN",     
  "IN",            "ISNULL",        "NOTNULL",       "NE",          
  "EQ",            "GT",            "LE",            "LT",          
  "GE",            "ESCAPE",        "BITAND",        "BITOR",       
  "LSHIFT",        "RSHIFT",        "PLUS",          "MINUS",       
  "STAR",          "SLASH",         "REM",           "CONCAT",      
  "COLLATE",       "BITNOT",        "STRING",        "JOIN_KW",     
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "INSERT",        "DELETE",        "UPDATE",      
  "SET",           "DEFERRABLE",    "FOREIGN",       "DROP",        
  "UNION",         "ALL",           "EXCEPT",        "INTERSECT",   
  "SELECT",        "DISTINCT",      "DOT",           "FROM",        
  "JOIN",          "USING",         "ORDER",         "GROUP",       
  "HAVING",        "LIMIT",         "WHERE",         "INTO",        
  "VALUES",        "INTEGER",       "FLOAT",         "BLOB",        
  "REGISTER",      "VARIABLE",      "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "error",       
  "input",         "cmdlist",       "ecmd",          "explain",     
  "cmdx",          "cmd",           "transtype",     "trans_opt",   
  "nm",            "savepoint_opt",  "create_table",  "create_table_args",
  "createkw",      "temp",          "ifnotexists",   "dbnm",        
  "columnlist",    "conslist_opt",  "select",        "column",      
  "columnid",      "type",          "carglist",      "id",          
  "ids",           "typetoken",     "typename",      "signed",      
  "plus_num",      "minus_num",     "carg",          "ccons",       
  "term",          "expr",          "onconf",        "sortorder",   
  "autoinc",       "idxlist_opt",   "refargs",       "defer_subclause",
  "refarg",        "refact",        "init_deferred_pred_opt",  "conslist",    
  "tcons",         "idxlist",       "defer_subclause_opt",  "orconf",      
  "resolvetype",   "raisetype",     "ifexists",      "fullname",    
  "oneselect",     "multiselect_op",  "distinct",      "selcollist",  
  "from",          "where_opt",     "groupby_opt",   "having_opt",  
  "orderby_opt",   "limit_opt",     "sclp",          "as",          
  "seltablist",    "stl_prefix",    "joinop",        "indexed_opt", 
  "on_opt",        "using_opt",     "joinop2",       "inscollist",  
  "sortlist",      "sortitem",      "nexprlist",     "setlist",     
  "insert_cmd",    "inscollist_opt",  "itemlist",      "exprlist",    
  "likeop",        "between_op",    "in_op",         "case_operand",
  "case_exprlist",  "case_else",     "uniqueflag",    "collate",     
  "nmnum",         "plus_opt",      "number",        "trigger_decl",
  "trigger_cmd_list",  "trigger_time",  "trigger_event",  "foreach_clause",
  "when_clause",   "trigger_cmd",   "trnm",          "tridxby",     
  "create_vtab",   "vtabarglist",   "vtabarg",       "vtabargtoken",
  "lp",            "anylist",     
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "input ::= cmdlist",
 /*   1 */ "cmdlist ::= cmdlist ecmd",
 /*   2 */ "cmdlist ::= ecmd",
 /*   3 */ "ecmd ::= SEMI",
 /*   4 */ "ecmd ::= explain cmdx SEMI",
 /*   5 */ "explain ::=",
 /*   6 */ "cmdx ::= cmd",
 /*   7 */ "cmd ::= BEGIN transtype trans_opt",
 /*   8 */ "trans_opt ::=",
 /*   9 */ "trans_opt ::= TRANSACTION",
 /*  10 */ "trans_opt ::= TRANSACTION nm",
 /*  11 */ "transtype ::=",
 /*  12 */ "transtype ::= DEFERRED",
 /*  13 */ "transtype ::= IMMEDIATE",
 /*  14 */ "transtype ::= EXCLUSIVE",
 /*  15 */ "cmd ::= COMMIT trans_opt",
 /*  16 */ "cmd ::= END trans_opt",
 /*  17 */ "cmd ::= ROLLBACK trans_opt",
 /*  18 */ "savepoint_opt ::= SAVEPOINT",
 /*  19 */ "savepoint_opt ::=",
 /*  20 */ "cmd ::= SAVEPOINT nm",
 /*  21 */ "cmd ::= RELEASE savepoint_opt nm",
 /*  22 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt nm",
 /*  23 */ "cmd ::= create_table create_table_args",
 /*  24 */ "create_table ::= createkw temp TABLE ifnotexists nm dbnm",
 /*  25 */ "createkw ::= CREATE",
 /*  26 */ "ifnotexists ::=",
 /*  27 */ "ifnotexists ::= IF NOT EXISTS",
 /*  28 */ "temp ::=",
 /*  29 */ "create_table_args ::= LP columnlist conslist_opt RP",
 /*  30 */ "create_table_args ::= AS select",
 /*  31 */ "columnlist ::= columnlist COMMA column",
 /*  32 */ "columnlist ::= column",
 /*  33 */ "column ::= columnid type carglist",
 /*  34 */ "columnid ::= nm",
 /*  35 */ "id ::= ID",
 /*  36 */ "id ::= INDEXED",
 /*  37 */ "ids ::= ID|STRING",
 /*  38 */ "nm ::= id",
 /*  39 */ "nm ::= STRING",
 /*  40 */ "nm ::= JOIN_KW",
 /*  41 */ "type ::=",
 /*  42 */ "type ::= typetoken",
 /*  43 */ "typetoken ::= typename",
 /*  44 */ "typetoken ::= typename LP signed RP",
 /*  45 */ "typetoken ::= typename LP signed COMMA signed RP",
 /*  46 */ "typename ::= ids",
 /*  47 */ "typename ::= typename ids",
 /*  48 */ "signed ::= plus_num",
 /*  49 */ "signed ::= minus_num",
 /*  50 */ "carglist ::= carglist carg",
 /*  51 */ "carglist ::=",
 /*  52 */ "carg ::= CONSTRAINT nm ccons",
 /*  53 */ "carg ::= ccons",
 /*  54 */ "ccons ::= DEFAULT term",
 /*  55 */ "ccons ::= DEFAULT LP expr RP",
 /*  56 */ "ccons ::= DEFAULT PLUS term",
 /*  57 */ "ccons ::= DEFAULT MINUS term",
 /*  58 */ "ccons ::= DEFAULT id",
 /*  59 */ "ccons ::= NULL onconf",
 /*  60 */ "ccons ::= NOT NULL onconf",
 /*  61 */ "ccons ::= PRIMARY KEY sortorder onconf autoinc",
 /*  62 */ "ccons ::= UNIQUE onconf",
 /*  63 */ "ccons ::= CHECK LP expr RP",
 /*  64 */ "ccons ::= REFERENCES nm idxlist_opt refargs",
 /*  65 */ "ccons ::= defer_subclause",
 /*  66 */ "ccons ::= COLLATE ids",
 /*  67 */ "autoinc ::=",
 /*  68 */ "autoinc ::= AUTOINCR",
 /*  69 */ "refargs ::=",
 /*  70 */ "refargs ::= refargs refarg",
 /*  71 */ "refarg ::= MATCH nm",
 /*  72 */ "refarg ::= ON INSERT refact",
 /*  73 */ "refarg ::= ON DELETE refact",
 /*  74 */ "refarg ::= ON UPDATE refact",
 /*  75 */ "refact ::= SET NULL",
 /*  76 */ "refact ::= SET DEFAULT",
 /*  77 */ "refact ::= CASCADE",
 /*  78 */ "refact ::= RESTRICT",
 /*  79 */ "refact ::= NO ACTION",
 /*  80 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  81 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  82 */ "init_deferred_pred_opt ::=",
 /*  83 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  84 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  85 */ "conslist_opt ::=",
 /*  86 */ "conslist_opt ::= COMMA conslist",
 /*  87 */ "conslist ::= conslist COMMA tcons",
 /*  88 */ "conslist ::= conslist tcons",
 /*  89 */ "conslist ::= tcons",
 /*  90 */ "tcons ::= CONSTRAINT nm",
 /*  91 */ "tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf",
 /*  92 */ "tcons ::= UNIQUE LP idxlist RP onconf",
 /*  93 */ "tcons ::= CHECK LP expr RP onconf",
 /*  94 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
 /*  95 */ "defer_subclause_opt ::=",
 /*  96 */ "defer_subclause_opt ::= defer_subclause",
 /*  97 */ "onconf ::=",
 /*  98 */ "onconf ::= ON CONFLICT resolvetype",
 /*  99 */ "orconf ::=",
 /* 100 */ "orconf ::= OR resolvetype",
 /* 101 */ "resolvetype ::= raisetype",
 /* 102 */ "resolvetype ::= IGNORE",
 /* 103 */ "resolvetype ::= REPLACE",
 /* 104 */ "cmd ::= DROP TABLE ifexists fullname",
 /* 105 */ "ifexists ::= IF EXISTS",
 /* 106 */ "ifexists ::=",
 /* 107 */ "cmd ::= select",
 /* 108 */ "select ::= oneselect",
 /* 109 */ "select ::= select multiselect_op oneselect",
 /* 110 */ "multiselect_op ::= UNION",
 /* 111 */ "multiselect_op ::= UNION ALL",
 /* 112 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /* 113 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /* 114 */ "distinct ::= DISTINCT",
 /* 115 */ "distinct ::= ALL",
 /* 116 */ "distinct ::=",
 /* 117 */ "sclp ::= selcollist COMMA",
 /* 118 */ "sclp ::=",
 /* 119 */ "selcollist ::= sclp expr as",
 /* 120 */ "selcollist ::= sclp STAR",
 /* 121 */ "selcollist ::= sclp nm DOT STAR",
 /* 122 */ "as ::= AS nm",
 /* 123 */ "as ::= ids",
 /* 124 */ "as ::=",
 /* 125 */ "from ::=",
 /* 126 */ "from ::= FROM seltablist",
 /* 127 */ "stl_prefix ::= seltablist joinop",
 /* 128 */ "stl_prefix ::=",
 /* 129 */ "seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt",
 /* 130 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /* 131 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /* 132 */ "dbnm ::=",
 /* 133 */ "dbnm ::= DOT nm",
 /* 134 */ "fullname ::= nm dbnm",
 /* 135 */ "joinop ::= COMMA|JOIN",
 /* 136 */ "joinop ::= JOIN_KW JOIN",
 /* 137 */ "joinop ::= JOIN_KW nm JOIN",
 /* 138 */ "joinop ::= JOIN_KW nm nm JOIN",
 /* 139 */ "on_opt ::= ON expr",
 /* 140 */ "on_opt ::=",
 /* 141 */ "indexed_opt ::=",
 /* 142 */ "indexed_opt ::= INDEXED BY nm",
 /* 143 */ "indexed_opt ::= NOT INDEXED",
 /* 144 */ "using_opt ::= USING LP inscollist RP",
 /* 145 */ "using_opt ::=",
 /* 146 */ "orderby_opt ::=",
 /* 147 */ "orderby_opt ::= ORDER BY sortlist",
 /* 148 */ "sortlist ::= sortlist COMMA sortitem sortorder",
 /* 149 */ "sortlist ::= sortitem sortorder",
 /* 150 */ "sortitem ::= expr",
 /* 151 */ "sortorder ::= ASC",
 /* 152 */ "sortorder ::= DESC",
 /* 153 */ "sortorder ::=",
 /* 154 */ "groupby_opt ::=",
 /* 155 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 156 */ "having_opt ::=",
 /* 157 */ "having_opt ::= HAVING expr",
 /* 158 */ "limit_opt ::=",
 /* 159 */ "limit_opt ::= LIMIT expr",
 /* 160 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 161 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 162 */ "cmd ::= DELETE FROM fullname indexed_opt where_opt orderby_opt limit_opt",
 /* 163 */ "where_opt ::=",
 /* 164 */ "where_opt ::= WHERE expr",
 /* 165 */ "cmd ::= UPDATE orconf fullname indexed_opt SET setlist where_opt orderby_opt limit_opt",
 /* 166 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 167 */ "setlist ::= nm EQ expr",
 /* 168 */ "cmd ::= insert_cmd INTO fullname inscollist_opt VALUES LP itemlist RP",
 /* 169 */ "cmd ::= insert_cmd INTO fullname inscollist_opt select",
 /* 170 */ "cmd ::= insert_cmd INTO fullname inscollist_opt DEFAULT VALUES",
 /* 171 */ "insert_cmd ::= INSERT orconf",
 /* 172 */ "insert_cmd ::= REPLACE",
 /* 173 */ "itemlist ::= itemlist COMMA expr",
 /* 174 */ "itemlist ::= expr",
 /* 175 */ "inscollist_opt ::=",
 /* 176 */ "inscollist_opt ::= LP inscollist RP",
 /* 177 */ "inscollist ::= inscollist COMMA nm",
 /* 178 */ "inscollist ::= nm",
 /* 179 */ "expr ::= term",
 /* 180 */ "expr ::= LP expr RP",
 /* 181 */ "term ::= NULL",
 /* 182 */ "expr ::= id",
 /* 183 */ "expr ::= JOIN_KW",
 /* 184 */ "expr ::= nm DOT nm",
 /* 185 */ "expr ::= nm DOT nm DOT nm",
 /* 186 */ "term ::= INTEGER|FLOAT|BLOB",
 /* 187 */ "term ::= STRING",
 /* 188 */ "expr ::= REGISTER",
 /* 189 */ "expr ::= VARIABLE",
 /* 190 */ "expr ::= expr COLLATE ids",
 /* 191 */ "expr ::= CAST LP expr AS typetoken RP",
 /* 192 */ "expr ::= ID LP distinct exprlist RP",
 /* 193 */ "expr ::= ID LP STAR RP",
 /* 194 */ "term ::= CTIME_KW",
 /* 195 */ "expr ::= expr AND expr",
 /* 196 */ "expr ::= expr OR expr",
 /* 197 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 198 */ "expr ::= expr EQ|NE expr",
 /* 199 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 200 */ "expr ::= expr PLUS|MINUS expr",
 /* 201 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 202 */ "expr ::= expr CONCAT expr",
 /* 203 */ "likeop ::= LIKE_KW",
 /* 204 */ "likeop ::= NOT LIKE_KW",
 /* 205 */ "likeop ::= MATCH",
 /* 206 */ "likeop ::= NOT MATCH",
 /* 207 */ "expr ::= expr likeop expr",
 /* 208 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 209 */ "expr ::= expr ISNULL|NOTNULL",
 /* 210 */ "expr ::= expr NOT NULL",
 /* 211 */ "expr ::= expr IS expr",
 /* 212 */ "expr ::= expr IS NOT expr",
 /* 213 */ "expr ::= NOT expr",
 /* 214 */ "expr ::= BITNOT expr",
 /* 215 */ "expr ::= MINUS expr",
 /* 216 */ "expr ::= PLUS expr",
 /* 217 */ "between_op ::= BETWEEN",
 /* 218 */ "between_op ::= NOT BETWEEN",
 /* 219 */ "expr ::= expr between_op expr AND expr",
 /* 220 */ "in_op ::= IN",
 /* 221 */ "in_op ::= NOT IN",
 /* 222 */ "expr ::= expr in_op LP exprlist RP",
 /* 223 */ "expr ::= LP select RP",
 /* 224 */ "expr ::= expr in_op LP select RP",
 /* 225 */ "expr ::= expr in_op nm dbnm",
 /* 226 */ "expr ::= EXISTS LP select RP",
 /* 227 */ "expr ::= CASE case_operand case_exprlist case_else END",
 /* 228 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 229 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 230 */ "case_else ::= ELSE expr",
 /* 231 */ "case_else ::=",
 /* 232 */ "case_operand ::= expr",
 /* 233 */ "case_operand ::=",
 /* 234 */ "exprlist ::= nexprlist",
 /* 235 */ "exprlist ::=",
 /* 236 */ "nexprlist ::= nexprlist COMMA expr",
 /* 237 */ "nexprlist ::= expr",
 /* 238 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm dbnm ON nm LP idxlist RP",
 /* 239 */ "uniqueflag ::= UNIQUE",
 /* 240 */ "uniqueflag ::=",
 /* 241 */ "idxlist_opt ::=",
 /* 242 */ "idxlist_opt ::= LP idxlist RP",
 /* 243 */ "idxlist ::= idxlist COMMA nm collate sortorder",
 /* 244 */ "idxlist ::= nm collate sortorder",
 /* 245 */ "collate ::=",
 /* 246 */ "collate ::= COLLATE ids",
 /* 247 */ "cmd ::= DROP INDEX ifexists fullname",
 /* 248 */ "cmd ::= PRAGMA nm dbnm",
 /* 249 */ "cmd ::= PRAGMA nm dbnm EQ nmnum",
 /* 250 */ "cmd ::= PRAGMA nm dbnm LP nmnum RP",
 /* 251 */ "cmd ::= PRAGMA nm dbnm EQ minus_num",
 /* 252 */ "cmd ::= PRAGMA nm dbnm LP minus_num RP",
 /* 253 */ "nmnum ::= plus_num",
 /* 254 */ "nmnum ::= nm",
 /* 255 */ "nmnum ::= ON",
 /* 256 */ "nmnum ::= DELETE",
 /* 257 */ "nmnum ::= DEFAULT",
 /* 258 */ "plus_num ::= plus_opt number",
 /* 259 */ "minus_num ::= MINUS number",
 /* 260 */ "number ::= INTEGER|FLOAT",
 /* 261 */ "plus_opt ::= PLUS",
 /* 262 */ "plus_opt ::=",
 /* 263 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 264 */ "trigger_decl ::= temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 265 */ "trigger_time ::= BEFORE",
 /* 266 */ "trigger_time ::= AFTER",
 /* 267 */ "trigger_time ::= INSTEAD OF",
 /* 268 */ "trigger_time ::=",
 /* 269 */ "trigger_event ::= DELETE|INSERT",
 /* 270 */ "trigger_event ::= UPDATE",
 /* 271 */ "trigger_event ::= UPDATE OF inscollist",
 /* 272 */ "foreach_clause ::=",
 /* 273 */ "foreach_clause ::= FOR EACH ROW",
 /* 274 */ "when_clause ::=",
 /* 275 */ "when_clause ::= WHEN expr",
 /* 276 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 277 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 278 */ "trnm ::= nm",
 /* 279 */ "trnm ::= nm DOT nm",
 /* 280 */ "tridxby ::=",
 /* 281 */ "tridxby ::= INDEXED BY nm",
 /* 282 */ "tridxby ::= NOT INDEXED",
 /* 283 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 284 */ "trigger_cmd ::= insert_cmd INTO trnm inscollist_opt VALUES LP itemlist RP",
 /* 285 */ "trigger_cmd ::= insert_cmd INTO trnm inscollist_opt select",
 /* 286 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 287 */ "trigger_cmd ::= select",
 /* 288 */ "expr ::= RAISE LP IGNORE RP",
 /* 289 */ "expr ::= RAISE LP raisetype COMMA nm RP",
 /* 290 */ "raisetype ::= ROLLBACK",
 /* 291 */ "raisetype ::= ABORT",
 /* 292 */ "raisetype ::= FAIL",
 /* 293 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 294 */ "cmd ::= REINDEX",
 /* 295 */ "cmd ::= REINDEX nm dbnm",
 /* 296 */ "cmd ::= ANALYZE",
 /* 297 */ "cmd ::= ANALYZE nm dbnm",
 /* 298 */ "cmd ::= create_vtab",
 /* 299 */ "cmd ::= create_vtab LP vtabarglist RP",
 /* 300 */ "create_vtab ::= createkw VIRTUAL TABLE nm dbnm USING nm",
 /* 301 */ "vtabarglist ::= vtabarg",
 /* 302 */ "vtabarglist ::= vtabarglist COMMA vtabarg",
 /* 303 */ "vtabarg ::=",
 /* 304 */ "vtabarg ::= vtabarg vtabargtoken",
 /* 305 */ "vtabargtoken ::= ANY",
 /* 306 */ "vtabargtoken ::= lp anylist RP",
 /* 307 */ "lp ::= LP",
 /* 308 */ "anylist ::=",
 /* 309 */ "anylist ::= anylist LP anylist RP",
 /* 310 */ "anylist ::= anylist ANY",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlite3Parser and sqlite3ParserFree.
*/
void *sqlite3ParserAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlite3ParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
    case 158: /* select */
    case 192: /* oneselect */
{
#line 403 "parse.y"
sqlite3SelectDelete(pParse->db, (yypminor->yy375));
#line 1357 "parse.c"
}
      break;
    case 172: /* term */
    case 173: /* expr */
{
#line 720 "parse.y"
sqlite3ExprDelete(pParse->db, (yypminor->yy370).pExpr);
#line 1365 "parse.c"
}
      break;
    case 177: /* idxlist_opt */
    case 185: /* idxlist */
    case 195: /* selcollist */
    case 198: /* groupby_opt */
    case 200: /* orderby_opt */
    case 202: /* sclp */
    case 212: /* sortlist */
    case 214: /* nexprlist */
    case 215: /* setlist */
    case 218: /* itemlist */
    case 219: /* exprlist */
    case 224: /* case_exprlist */
{
#line 1103 "parse.y"
sqlite3ExprListDelete(pParse->db, (yypminor->yy418));
#line 1383 "parse.c"
}
      break;
    case 191: /* fullname */
    case 196: /* from */
    case 204: /* seltablist */
    case 205: /* stl_prefix */
{
#line 534 "parse.y"
sqlite3SrcListDelete(pParse->db, (yypminor->yy151));
#line 1393 "parse.c"
}
      break;
    case 197: /* where_opt */
    case 199: /* having_opt */
    case 208: /* on_opt */
    case 213: /* sortitem */
    case 223: /* case_operand */
    case 225: /* case_else */
    case 236: /* when_clause */
{
#line 644 "parse.y"
sqlite3ExprDelete(pParse->db, (yypminor->yy62));
#line 1406 "parse.c"
}
      break;
    case 209: /* using_opt */
    case 211: /* inscollist */
    case 217: /* inscollist_opt */
{
#line 566 "parse.y"
sqlite3IdListDelete(pParse->db, (yypminor->yy240));
#line 1415 "parse.c"
}
      break;
    case 232: /* trigger_cmd_list */
    case 237: /* trigger_cmd */
{
#line 1210 "parse.y"
sqlite3DeleteTriggerStep(pParse->db, (yypminor->yy360));
#line 1423 "parse.c"
}
      break;
    case 234: /* trigger_event */
{
#line 1196 "parse.y"
sqlite3IdListDelete(pParse->db, (yypminor->yy30).b);
#line 1430 "parse.c"
}
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  /* There is no mechanism by which the parser stack can be popped below
  ** empty in SQLite.  */
  if( NEVER(pParser->yyidx<0) ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from sqlite3ParserAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void sqlite3ParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  /* In SQLite, we never try to destroy a parser that was not successfully
  ** created in the first place. */
  if( NEVER(pParser==0) ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlite3ParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_COUNT
   || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   sqlite3ParserARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
#line 38 "parse.y"

  UNUSED_PARAMETER(yypMinor); /* Silence some compiler warnings */
  sqlite3ErrorMsg(pParse, "parser stack overflow");
  pParse->parseError = 1;
#line 1621 "parse.c"
   sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 140, 1 },
  { 141, 2 },
  { 141, 1 },
  { 142, 1 },
  { 142, 3 },
  { 143, 0 },
  { 144, 1 },
  { 145, 3 },
  { 147, 0 },
  { 147, 1 },
  { 147, 2 },
  { 146, 0 },
  { 146, 1 },
  { 146, 1 },
  { 146, 1 },
  { 145, 2 },
  { 145, 2 },
  { 145, 2 },
  { 149, 1 },
  { 149, 0 },
  { 145, 2 },
  { 145, 3 },
  { 145, 5 },
  { 145, 2 },
  { 150, 6 },
  { 152, 1 },
  { 154, 0 },
  { 154, 3 },
  { 153, 0 },
  { 151, 4 },
  { 151, 2 },
  { 156, 3 },
  { 156, 1 },
  { 159, 3 },
  { 160, 1 },
  { 163, 1 },
  { 163, 1 },
  { 164, 1 },
  { 148, 1 },
  { 148, 1 },
  { 148, 1 },
  { 161, 0 },
  { 161, 1 },
  { 165, 1 },
  { 165, 4 },
  { 165, 6 },
  { 166, 1 },
  { 166, 2 },
  { 167, 1 },
  { 167, 1 },
  { 162, 2 },
  { 162, 0 },
  { 170, 3 },
  { 170, 1 },
  { 171, 2 },
  { 171, 4 },
  { 171, 3 },
  { 171, 3 },
  { 171, 2 },
  { 171, 2 },
  { 171, 3 },
  { 171, 5 },
  { 171, 2 },
  { 171, 4 },
  { 171, 4 },
  { 171, 1 },
  { 171, 2 },
  { 176, 0 },
  { 176, 1 },
  { 178, 0 },
  { 178, 2 },
  { 180, 2 },
  { 180, 3 },
  { 180, 3 },
  { 180, 3 },
  { 181, 2 },
  { 181, 2 },
  { 181, 1 },
  { 181, 1 },
  { 181, 2 },
  { 179, 3 },
  { 179, 2 },
  { 182, 0 },
  { 182, 2 },
  { 182, 2 },
  { 157, 0 },
  { 157, 2 },
  { 183, 3 },
  { 183, 2 },
  { 183, 1 },
  { 184, 2 },
  { 184, 7 },
  { 184, 5 },
  { 184, 5 },
  { 184, 10 },
  { 186, 0 },
  { 186, 1 },
  { 174, 0 },
  { 174, 3 },
  { 187, 0 },
  { 187, 2 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 145, 4 },
  { 190, 2 },
  { 190, 0 },
  { 145, 1 },
  { 158, 1 },
  { 158, 3 },
  { 193, 1 },
  { 193, 2 },
  { 193, 1 },
  { 192, 9 },
  { 194, 1 },
  { 194, 1 },
  { 194, 0 },
  { 202, 2 },
  { 202, 0 },
  { 195, 3 },
  { 195, 2 },
  { 195, 4 },
  { 203, 2 },
  { 203, 1 },
  { 203, 0 },
  { 196, 0 },
  { 196, 2 },
  { 205, 2 },
  { 205, 0 },
  { 204, 7 },
  { 204, 7 },
  { 204, 7 },
  { 155, 0 },
  { 155, 2 },
  { 191, 2 },
  { 206, 1 },
  { 206, 2 },
  { 206, 3 },
  { 206, 4 },
  { 208, 2 },
  { 208, 0 },
  { 207, 0 },
  { 207, 3 },
  { 207, 2 },
  { 209, 4 },
  { 209, 0 },
  { 200, 0 },
  { 200, 3 },
  { 212, 4 },
  { 212, 2 },
  { 213, 1 },
  { 175, 1 },
  { 175, 1 },
  { 175, 0 },
  { 198, 0 },
  { 198, 3 },
  { 199, 0 },
  { 199, 2 },
  { 201, 0 },
  { 201, 2 },
  { 201, 4 },
  { 201, 4 },
  { 145, 7 },
  { 197, 0 },
  { 197, 2 },
  { 145, 9 },
  { 215, 5 },
  { 215, 3 },
  { 145, 8 },
  { 145, 5 },
  { 145, 6 },
  { 216, 2 },
  { 216, 1 },
  { 218, 3 },
  { 218, 1 },
  { 217, 0 },
  { 217, 3 },
  { 211, 3 },
  { 211, 1 },
  { 173, 1 },
  { 173, 3 },
  { 172, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 3 },
  { 173, 5 },
  { 172, 1 },
  { 172, 1 },
  { 173, 1 },
  { 173, 1 },
  { 173, 3 },
  { 173, 6 },
  { 173, 5 },
  { 173, 4 },
  { 172, 1 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 173, 3 },
  { 220, 1 },
  { 220, 2 },
  { 220, 1 },
  { 220, 2 },
  { 173, 3 },
  { 173, 5 },
  { 173, 2 },
  { 173, 3 },
  { 173, 3 },
  { 173, 4 },
  { 173, 2 },
  { 173, 2 },
  { 173, 2 },
  { 173, 2 },
  { 221, 1 },
  { 221, 2 },
  { 173, 5 },
  { 222, 1 },
  { 222, 2 },
  { 173, 5 },
  { 173, 3 },
  { 173, 5 },
  { 173, 4 },
  { 173, 4 },
  { 173, 5 },
  { 224, 5 },
  { 224, 4 },
  { 225, 2 },
  { 225, 0 },
  { 223, 1 },
  { 223, 0 },
  { 219, 1 },
  { 219, 0 },
  { 214, 3 },
  { 214, 1 },
  { 145, 11 },
  { 226, 1 },
  { 226, 0 },
  { 177, 0 },
  { 177, 3 },
  { 185, 5 },
  { 185, 3 },
  { 227, 0 },
  { 227, 2 },
  { 145, 4 },
  { 145, 3 },
  { 145, 5 },
  { 145, 6 },
  { 145, 5 },
  { 145, 6 },
  { 228, 1 },
  { 228, 1 },
  { 228, 1 },
  { 228, 1 },
  { 228, 1 },
  { 168, 2 },
  { 169, 2 },
  { 230, 1 },
  { 229, 1 },
  { 229, 0 },
  { 145, 5 },
  { 231, 11 },
  { 233, 1 },
  { 233, 1 },
  { 233, 2 },
  { 233, 0 },
  { 234, 1 },
  { 234, 1 },
  { 234, 3 },
  { 235, 0 },
  { 235, 3 },
  { 236, 0 },
  { 236, 2 },
  { 232, 3 },
  { 232, 2 },
  { 238, 1 },
  { 238, 3 },
  { 239, 0 },
  { 239, 3 },
  { 239, 2 },
  { 237, 7 },
  { 237, 8 },
  { 237, 5 },
  { 237, 5 },
  { 237, 1 },
  { 173, 4 },
  { 173, 6 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 145, 4 },
  { 145, 1 },
  { 145, 3 },
  { 145, 1 },
  { 145, 3 },
  { 145, 1 },
  { 145, 4 },
  { 240, 7 },
  { 241, 1 },
  { 241, 3 },
  { 242, 0 },
  { 242, 2 },
  { 243, 1 },
  { 243, 3 },
  { 244, 1 },
  { 245, 0 },
  { 245, 4 },
  { 245, 2 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlite3ParserARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 5: /* explain ::= */
#line 107 "parse.y"
{ sqlite3BeginParse(pParse, 0); }
#line 2046 "parse.c"
        break;
      case 6: /* cmdx ::= cmd */
#line 112 "parse.y"
{ sqlite3FinishCoding(pParse); }
#line 2051 "parse.c"
        break;
      case 7: /* cmd ::= BEGIN transtype trans_opt */
#line 117 "parse.y"
{sqlite3BeginTransaction(pParse, yymsp[-1].minor.yy280);}
#line 2056 "parse.c"
        break;
      case 11: /* transtype ::= */
#line 122 "parse.y"
{yygotominor.yy280 = TK_DEFERRED;}
#line 2061 "parse.c"
        break;
      case 12: /* transtype ::= DEFERRED */
      case 13: /* transtype ::= IMMEDIATE */ yytestcase(yyruleno==13);
      case 14: /* transtype ::= EXCLUSIVE */ yytestcase(yyruleno==14);
      case 110: /* multiselect_op ::= UNION */ yytestcase(yyruleno==110);
      case 112: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==112);
#line 123 "parse.y"
{yygotominor.yy280 = yymsp[0].major;}
#line 2070 "parse.c"
        break;
      case 15: /* cmd ::= COMMIT trans_opt */
      case 16: /* cmd ::= END trans_opt */ yytestcase(yyruleno==16);
#line 126 "parse.y"
{sqlite3CommitTransaction(pParse);}
#line 2076 "parse.c"
        break;
      case 17: /* cmd ::= ROLLBACK trans_opt */
#line 128 "parse.y"
{sqlite3RollbackTransaction(pParse);}
#line 2081 "parse.c"
        break;
      case 20: /* cmd ::= SAVEPOINT nm */
#line 132 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2088 "parse.c"
        break;
      case 21: /* cmd ::= RELEASE savepoint_opt nm */
#line 135 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2095 "parse.c"
        break;
      case 22: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt nm */
#line 138 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2102 "parse.c"
        break;
      case 24: /* create_table ::= createkw temp TABLE ifnotexists nm dbnm */
#line 145 "parse.y"
{
   sqlite3StartTable(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,yymsp[-4].minor.yy280,0,0,yymsp[-2].minor.yy280);
}
#line 2109 "parse.c"
        break;
      case 25: /* createkw ::= CREATE */
#line 148 "parse.y"
{
  pParse->db->lookaside.bEnabled = 0;
  yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 2117 "parse.c"
        break;
      case 26: /* ifnotexists ::= */
      case 28: /* temp ::= */ yytestcase(yyruleno==28);
      case 67: /* autoinc ::= */ yytestcase(yyruleno==67);
      case 80: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */ yytestcase(yyruleno==80);
      case 82: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==82);
      case 84: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */ yytestcase(yyruleno==84);
      case 95: /* defer_subclause_opt ::= */ yytestcase(yyruleno==95);
      case 106: /* ifexists ::= */ yytestcase(yyruleno==106);
      case 115: /* distinct ::= ALL */ yytestcase(yyruleno==115);
      case 116: /* distinct ::= */ yytestcase(yyruleno==116);
      case 217: /* between_op ::= BETWEEN */ yytestcase(yyruleno==217);
      case 220: /* in_op ::= IN */ yytestcase(yyruleno==220);
#line 153 "parse.y"
{yygotominor.yy280 = 0;}
#line 2133 "parse.c"
        break;
      case 27: /* ifnotexists ::= IF NOT EXISTS */
      case 68: /* autoinc ::= AUTOINCR */ yytestcase(yyruleno==68);
      case 83: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */ yytestcase(yyruleno==83);
      case 105: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==105);
      case 114: /* distinct ::= DISTINCT */ yytestcase(yyruleno==114);
      case 218: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==218);
      case 221: /* in_op ::= NOT IN */ yytestcase(yyruleno==221);
#line 154 "parse.y"
{yygotominor.yy280 = 1;}
#line 2144 "parse.c"
        break;
      case 29: /* create_table_args ::= LP columnlist conslist_opt RP */
#line 160 "parse.y"
{
  sqlite3EndTable(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,0);
}
#line 2151 "parse.c"
        break;
      case 30: /* create_table_args ::= AS select */
#line 163 "parse.y"
{
  sqlite3EndTable(pParse,0,0,yymsp[0].minor.yy375);
  sqlite3SelectDelete(pParse->db, yymsp[0].minor.yy375);
}
#line 2159 "parse.c"
        break;
      case 33: /* column ::= columnid type carglist */
#line 175 "parse.y"
{
  yygotominor.yy0.z = yymsp[-2].minor.yy0.z;
  yygotominor.yy0.n = (int)(pParse->sLastToken.z-yymsp[-2].minor.yy0.z) + pParse->sLastToken.n;
}
#line 2167 "parse.c"
        break;
      case 34: /* columnid ::= nm */
#line 179 "parse.y"
{
  sqlite3AddColumn(pParse,&yymsp[0].minor.yy0);
  yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 2175 "parse.c"
        break;
      case 35: /* id ::= ID */
      case 36: /* id ::= INDEXED */ yytestcase(yyruleno==36);
      case 37: /* ids ::= ID|STRING */ yytestcase(yyruleno==37);
      case 38: /* nm ::= id */ yytestcase(yyruleno==38);
      case 39: /* nm ::= STRING */ yytestcase(yyruleno==39);
      case 40: /* nm ::= JOIN_KW */ yytestcase(yyruleno==40);
      case 43: /* typetoken ::= typename */ yytestcase(yyruleno==43);
      case 46: /* typename ::= ids */ yytestcase(yyruleno==46);
      case 122: /* as ::= AS nm */ yytestcase(yyruleno==122);
      case 123: /* as ::= ids */ yytestcase(yyruleno==123);
      case 133: /* dbnm ::= DOT nm */ yytestcase(yyruleno==133);
      case 142: /* indexed_opt ::= INDEXED BY nm */ yytestcase(yyruleno==142);
      case 246: /* collate ::= COLLATE ids */ yytestcase(yyruleno==246);
      case 253: /* nmnum ::= plus_num */ yytestcase(yyruleno==253);
      case 254: /* nmnum ::= nm */ yytestcase(yyruleno==254);
      case 255: /* nmnum ::= ON */ yytestcase(yyruleno==255);
      case 256: /* nmnum ::= DELETE */ yytestcase(yyruleno==256);
      case 257: /* nmnum ::= DEFAULT */ yytestcase(yyruleno==257);
      case 258: /* plus_num ::= plus_opt number */ yytestcase(yyruleno==258);
      case 259: /* minus_num ::= MINUS number */ yytestcase(yyruleno==259);
      case 260: /* number ::= INTEGER|FLOAT */ yytestcase(yyruleno==260);
      case 278: /* trnm ::= nm */ yytestcase(yyruleno==278);
#line 189 "parse.y"
{yygotominor.yy0 = yymsp[0].minor.yy0;}
#line 2201 "parse.c"
        break;
      case 42: /* type ::= typetoken */
#line 251 "parse.y"
{sqlite3AddColumnType(pParse,&yymsp[0].minor.yy0);}
#line 2206 "parse.c"
        break;
      case 44: /* typetoken ::= typename LP signed RP */
#line 253 "parse.y"
{
  yygotominor.yy0.z = yymsp[-3].minor.yy0.z;
  yygotominor.yy0.n = (int)(&yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] - yymsp[-3].minor.yy0.z);
}
#line 2214 "parse.c"
        break;
      case 45: /* typetoken ::= typename LP signed COMMA signed RP */
#line 257 "parse.y"
{
  yygotominor.yy0.z = yymsp[-5].minor.yy0.z;
  yygotominor.yy0.n = (int)(&yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] - yymsp[-5].minor.yy0.z);
}
#line 2222 "parse.c"
        break;
      case 47: /* typename ::= typename ids */
#line 263 "parse.y"
{yygotominor.yy0.z=yymsp[-1].minor.yy0.z; yygotominor.yy0.n=yymsp[0].minor.yy0.n+(int)(yymsp[0].minor.yy0.z-yymsp[-1].minor.yy0.z);}
#line 2227 "parse.c"
        break;
      case 54: /* ccons ::= DEFAULT term */
      case 56: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==56);
#line 274 "parse.y"
{sqlite3AddDefaultValue(pParse,&yymsp[0].minor.yy370);}
#line 2233 "parse.c"
        break;
      case 55: /* ccons ::= DEFAULT LP expr RP */
#line 275 "parse.y"
{sqlite3AddDefaultValue(pParse,&yymsp[-1].minor.yy370);}
#line 2238 "parse.c"
        break;
      case 57: /* ccons ::= DEFAULT MINUS term */
#line 277 "parse.y"
{
  ExprSpan v;
  v.pExpr = sqlite3PExpr(pParse, TK_UMINUS, yymsp[0].minor.yy370.pExpr, 0, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy370.zEnd;
  sqlite3AddDefaultValue(pParse,&v);
}
#line 2249 "parse.c"
        break;
      case 58: /* ccons ::= DEFAULT id */
#line 284 "parse.y"
{
  ExprSpan v;
  spanExpr(&v, pParse, TK_STRING, &yymsp[0].minor.yy0);
  sqlite3AddDefaultValue(pParse,&v);
}
#line 2258 "parse.c"
        break;
      case 60: /* ccons ::= NOT NULL onconf */
#line 294 "parse.y"
{sqlite3AddNotNull(pParse, yymsp[0].minor.yy280);}
#line 2263 "parse.c"
        break;
      case 61: /* ccons ::= PRIMARY KEY sortorder onconf autoinc */
#line 296 "parse.y"
{sqlite3AddPrimaryKey(pParse,0,yymsp[-1].minor.yy280,yymsp[0].minor.yy280,yymsp[-2].minor.yy280);}
#line 2268 "parse.c"
        break;
      case 62: /* ccons ::= UNIQUE onconf */
#line 297 "parse.y"
{sqlite3CreateIndex(pParse,0,0,0,0,yymsp[0].minor.yy280,0,0,0,0);}
#line 2273 "parse.c"
        break;
      case 63: /* ccons ::= CHECK LP expr RP */
#line 298 "parse.y"
{sqlite3AddCheckConstraint(pParse,yymsp[-1].minor.yy370.pExpr);}
#line 2278 "parse.c"
        break;
      case 64: /* ccons ::= REFERENCES nm idxlist_opt refargs */
#line 300 "parse.y"
{sqlite3CreateForeignKey(pParse,0,&yymsp[-2].minor.yy0,yymsp[-1].minor.yy418,yymsp[0].minor.yy280);}
#line 2283 "parse.c"
        break;
      case 65: /* ccons ::= defer_subclause */
#line 301 "parse.y"
{sqlite3DeferForeignKey(pParse,yymsp[0].minor.yy280);}
#line 2288 "parse.c"
        break;
      case 66: /* ccons ::= COLLATE ids */
#line 302 "parse.y"
{sqlite3AddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2293 "parse.c"
        break;
      case 69: /* refargs ::= */
#line 315 "parse.y"
{ yygotominor.yy280 = OE_None*0x0101; /* EV: R-19803-45884 */}
#line 2298 "parse.c"
        break;
      case 70: /* refargs ::= refargs refarg */
#line 316 "parse.y"
{ yygotominor.yy280 = (yymsp[-1].minor.yy280 & ~yymsp[0].minor.yy359.mask) | yymsp[0].minor.yy359.value; }
#line 2303 "parse.c"
        break;
      case 71: /* refarg ::= MATCH nm */
      case 72: /* refarg ::= ON INSERT refact */ yytestcase(yyruleno==72);
#line 318 "parse.y"
{ yygotominor.yy359.value = 0;     yygotominor.yy359.mask = 0x000000; }
#line 2309 "parse.c"
        break;
      case 73: /* refarg ::= ON DELETE refact */
#line 320 "parse.y"
{ yygotominor.yy359.value = yymsp[0].minor.yy280;     yygotominor.yy359.mask = 0x0000ff; }
#line 2314 "parse.c"
        break;
      case 74: /* refarg ::= ON UPDATE refact */
#line 321 "parse.y"
{ yygotominor.yy359.value = yymsp[0].minor.yy280<<8;  yygotominor.yy359.mask = 0x00ff00; }
#line 2319 "parse.c"
        break;
      case 75: /* refact ::= SET NULL */
#line 323 "parse.y"
{ yygotominor.yy280 = OE_SetNull;  /* EV: R-33326-45252 */}
#line 2324 "parse.c"
        break;
      case 76: /* refact ::= SET DEFAULT */
#line 324 "parse.y"
{ yygotominor.yy280 = OE_SetDflt;  /* EV: R-33326-45252 */}
#line 2329 "parse.c"
        break;
      case 77: /* refact ::= CASCADE */
#line 325 "parse.y"
{ yygotominor.yy280 = OE_Cascade;  /* EV: R-33326-45252 */}
#line 2334 "parse.c"
        break;
      case 78: /* refact ::= RESTRICT */
#line 326 "parse.y"
{ yygotominor.yy280 = OE_Restrict; /* EV: R-33326-45252 */}
#line 2339 "parse.c"
        break;
      case 79: /* refact ::= NO ACTION */
#line 327 "parse.y"
{ yygotominor.yy280 = OE_None;     /* EV: R-33326-45252 */}
#line 2344 "parse.c"
        break;
      case 81: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 96: /* defer_subclause_opt ::= defer_subclause */ yytestcase(yyruleno==96);
      case 98: /* onconf ::= ON CONFLICT resolvetype */ yytestcase(yyruleno==98);
      case 101: /* resolvetype ::= raisetype */ yytestcase(yyruleno==101);
#line 330 "parse.y"
{yygotominor.yy280 = yymsp[0].minor.yy280;}
#line 2352 "parse.c"
        break;
      case 85: /* conslist_opt ::= */
#line 339 "parse.y"
{yygotominor.yy0.n = 0; yygotominor.yy0.z = 0;}
#line 2357 "parse.c"
        break;
      case 86: /* conslist_opt ::= COMMA conslist */
#line 340 "parse.y"
{yygotominor.yy0 = yymsp[-1].minor.yy0;}
#line 2362 "parse.c"
        break;
      case 91: /* tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf */
#line 346 "parse.y"
{sqlite3AddPrimaryKey(pParse,yymsp[-3].minor.yy418,yymsp[0].minor.yy280,yymsp[-2].minor.yy280,0);}
#line 2367 "parse.c"
        break;
      case 92: /* tcons ::= UNIQUE LP idxlist RP onconf */
#line 348 "parse.y"
{sqlite3CreateIndex(pParse,0,0,0,yymsp[-2].minor.yy418,yymsp[0].minor.yy280,0,0,0,0);}
#line 2372 "parse.c"
        break;
      case 93: /* tcons ::= CHECK LP expr RP onconf */
#line 350 "parse.y"
{sqlite3AddCheckConstraint(pParse,yymsp[-2].minor.yy370.pExpr);}
#line 2377 "parse.c"
        break;
      case 94: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt */
#line 352 "parse.y"
{
    sqlite3CreateForeignKey(pParse, yymsp[-6].minor.yy418, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy418, yymsp[-1].minor.yy280);
    sqlite3DeferForeignKey(pParse, yymsp[0].minor.yy280);
}
#line 2385 "parse.c"
        break;
      case 97: /* onconf ::= */
#line 366 "parse.y"
{yygotominor.yy280 = OE_Default;}
#line 2390 "parse.c"
        break;
      case 99: /* orconf ::= */
#line 368 "parse.y"
{yygotominor.yy354 = OE_Default;}
#line 2395 "parse.c"
        break;
      case 100: /* orconf ::= OR resolvetype */
#line 369 "parse.y"
{yygotominor.yy354 = (u8)yymsp[0].minor.yy280;}
#line 2400 "parse.c"
        break;
      case 102: /* resolvetype ::= IGNORE */
#line 371 "parse.y"
{yygotominor.yy280 = OE_Ignore;}
#line 2405 "parse.c"
        break;
      case 103: /* resolvetype ::= REPLACE */
#line 372 "parse.y"
{yygotominor.yy280 = OE_Replace;}
#line 2410 "parse.c"
        break;
      case 104: /* cmd ::= DROP TABLE ifexists fullname */
#line 376 "parse.y"
{
  sqlite3DropTable(pParse, yymsp[0].minor.yy151, 0, yymsp[-1].minor.yy280);
}
#line 2417 "parse.c"
        break;
      case 107: /* cmd ::= select */
#line 396 "parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0};
  sqlite3Select(pParse, yymsp[0].minor.yy375, &dest);
  sqlite3SelectDelete(pParse->db, yymsp[0].minor.yy375);
}
#line 2426 "parse.c"
        break;
      case 108: /* select ::= oneselect */
#line 407 "parse.y"
{yygotominor.yy375 = yymsp[0].minor.yy375;}
#line 2431 "parse.c"
        break;
      case 109: /* select ::= select multiselect_op oneselect */
#line 409 "parse.y"
{
  if( yymsp[0].minor.yy375 ){
    yymsp[0].minor.yy375->op = (u8)yymsp[-1].minor.yy280;
    yymsp[0].minor.yy375->pPrior = yymsp[-2].minor.yy375;
  }else{
    sqlite3SelectDelete(pParse->db, yymsp[-2].minor.yy375);
  }
  yygotominor.yy375 = yymsp[0].minor.yy375;
}
#line 2444 "parse.c"
        break;
      case 111: /* multiselect_op ::= UNION ALL */
#line 420 "parse.y"
{yygotominor.yy280 = TK_ALL;}
#line 2449 "parse.c"
        break;
      case 113: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 424 "parse.y"
{
  yygotominor.yy375 = sqlite3SelectNew(pParse,yymsp[-6].minor.yy418,yymsp[-5].minor.yy151,yymsp[-4].minor.yy62,yymsp[-3].minor.yy418,yymsp[-2].minor.yy62,yymsp[-1].minor.yy418,yymsp[-7].minor.yy280,yymsp[0].minor.yy220.pLimit,yymsp[0].minor.yy220.pOffset);
}
#line 2456 "parse.c"
        break;
      case 117: /* sclp ::= selcollist COMMA */
      case 242: /* idxlist_opt ::= LP idxlist RP */ yytestcase(yyruleno==242);
#line 445 "parse.y"
{yygotominor.yy418 = yymsp[-1].minor.yy418;}
#line 2462 "parse.c"
        break;
      case 118: /* sclp ::= */
      case 146: /* orderby_opt ::= */ yytestcase(yyruleno==146);
      case 154: /* groupby_opt ::= */ yytestcase(yyruleno==154);
      case 235: /* exprlist ::= */ yytestcase(yyruleno==235);
      case 241: /* idxlist_opt ::= */ yytestcase(yyruleno==241);
#line 446 "parse.y"
{yygotominor.yy418 = 0;}
#line 2471 "parse.c"
        break;
      case 119: /* selcollist ::= sclp expr as */
#line 447 "parse.y"
{
   yygotominor.yy418 = sqlite3ExprListAppend(pParse, yymsp[-2].minor.yy418, yymsp[-1].minor.yy370.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlite3ExprListSetName(pParse, yygotominor.yy418, &yymsp[0].minor.yy0, 1);
   sqlite3ExprListSetSpan(pParse,yygotominor.yy418,&yymsp[-1].minor.yy370);
}
#line 2480 "parse.c"
        break;
      case 120: /* selcollist ::= sclp STAR */
#line 452 "parse.y"
{
  Expr *p = sqlite3Expr(pParse->db, TK_ALL, 0);
  yygotominor.yy418 = sqlite3ExprListAppend(pParse, yymsp[-1].minor.yy418, p);
}
#line 2488 "parse.c"
        break;
      case 121: /* selcollist ::= sclp nm DOT STAR */
#line 456 "parse.y"
{
  Expr *pRight = sqlite3PExpr(pParse, TK_ALL, 0, 0, &yymsp[0].minor.yy0);
  Expr *pLeft = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *pDot = sqlite3PExpr(pParse, TK_DOT, pLeft, pRight, 0);
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,yymsp[-3].minor.yy418, pDot);
}
#line 2498 "parse.c"
        break;
      case 124: /* as ::= */
#line 469 "parse.y"
{yygotominor.yy0.n = 0;}
#line 2503 "parse.c"
        break;
      case 125: /* from ::= */
#line 481 "parse.y"
{yygotominor.yy151 = sqlite3DbMallocZero(pParse->db, sizeof(*yygotominor.yy151));}
#line 2508 "parse.c"
        break;
      case 126: /* from ::= FROM seltablist */
#line 482 "parse.y"
{
  yygotominor.yy151 = yymsp[0].minor.yy151;
  sqlite3SrcListShiftJoinType(yygotominor.yy151);
}
#line 2516 "parse.c"
        break;
      case 127: /* stl_prefix ::= seltablist joinop */
#line 490 "parse.y"
{
   yygotominor.yy151 = yymsp[-1].minor.yy151;
   if( ALWAYS(yygotominor.yy151 && yygotominor.yy151->nSrc>0) ) yygotominor.yy151->a[yygotominor.yy151->nSrc-1].jointype = (u8)yymsp[0].minor.yy280;
}
#line 2524 "parse.c"
        break;
      case 128: /* stl_prefix ::= */
#line 494 "parse.y"
{yygotominor.yy151 = 0;}
#line 2529 "parse.c"
        break;
      case 129: /* seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt */
#line 495 "parse.y"
{
  yygotominor.yy151 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy151,&yymsp[-5].minor.yy0,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy62,yymsp[0].minor.yy240);
  sqlite3SrcListIndexedBy(pParse, yygotominor.yy151, &yymsp[-2].minor.yy0);
}
#line 2537 "parse.c"
        break;
      case 130: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 501 "parse.y"
{
    yygotominor.yy151 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy151,0,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy375,yymsp[-1].minor.yy62,yymsp[0].minor.yy240);
  }
#line 2544 "parse.c"
        break;
      case 131: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 505 "parse.y"
{
    if( yymsp[-6].minor.yy151==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy62==0 && yymsp[0].minor.yy240==0 ){
      yygotominor.yy151 = yymsp[-4].minor.yy151;
    }else{
      Select *pSubquery;
      sqlite3SrcListShiftJoinType(yymsp[-4].minor.yy151);
      pSubquery = sqlite3SelectNew(pParse,0,yymsp[-4].minor.yy151,0,0,0,0,0,0,0);
      yygotominor.yy151 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy151,0,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy62,yymsp[0].minor.yy240);
    }
  }
#line 2558 "parse.c"
        break;
      case 132: /* dbnm ::= */
      case 141: /* indexed_opt ::= */ yytestcase(yyruleno==141);
#line 530 "parse.y"
{yygotominor.yy0.z=0; yygotominor.yy0.n=0;}
#line 2564 "parse.c"
        break;
      case 134: /* fullname ::= nm dbnm */
#line 535 "parse.y"
{yygotominor.yy151 = sqlite3SrcListAppend(pParse->db,0,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0);}
#line 2569 "parse.c"
        break;
      case 135: /* joinop ::= COMMA|JOIN */
#line 539 "parse.y"
{ yygotominor.yy280 = JT_INNER; }
#line 2574 "parse.c"
        break;
      case 136: /* joinop ::= JOIN_KW JOIN */
#line 540 "parse.y"
{ yygotominor.yy280 = sqlite3JoinType(pParse,&yymsp[-1].minor.yy0,0,0); }
#line 2579 "parse.c"
        break;
      case 137: /* joinop ::= JOIN_KW nm JOIN */
#line 541 "parse.y"
{ yygotominor.yy280 = sqlite3JoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); }
#line 2584 "parse.c"
        break;
      case 138: /* joinop ::= JOIN_KW nm nm JOIN */
#line 543 "parse.y"
{ yygotominor.yy280 = sqlite3JoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0); }
#line 2589 "parse.c"
        break;
      case 139: /* on_opt ::= ON expr */
      case 150: /* sortitem ::= expr */ yytestcase(yyruleno==150);
      case 157: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==157);
      case 164: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==164);
      case 230: /* case_else ::= ELSE expr */ yytestcase(yyruleno==230);
      case 232: /* case_operand ::= expr */ yytestcase(yyruleno==232);
#line 547 "parse.y"
{yygotominor.yy62 = yymsp[0].minor.yy370.pExpr;}
#line 2599 "parse.c"
        break;
      case 140: /* on_opt ::= */
      case 156: /* having_opt ::= */ yytestcase(yyruleno==156);
      case 163: /* where_opt ::= */ yytestcase(yyruleno==163);
      case 231: /* case_else ::= */ yytestcase(yyruleno==231);
      case 233: /* case_operand ::= */ yytestcase(yyruleno==233);
#line 548 "parse.y"
{yygotominor.yy62 = 0;}
#line 2608 "parse.c"
        break;
      case 143: /* indexed_opt ::= NOT INDEXED */
#line 563 "parse.y"
{yygotominor.yy0.z=0; yygotominor.yy0.n=1;}
#line 2613 "parse.c"
        break;
      case 144: /* using_opt ::= USING LP inscollist RP */
      case 176: /* inscollist_opt ::= LP inscollist RP */ yytestcase(yyruleno==176);
#line 567 "parse.y"
{yygotominor.yy240 = yymsp[-1].minor.yy240;}
#line 2619 "parse.c"
        break;
      case 145: /* using_opt ::= */
      case 175: /* inscollist_opt ::= */ yytestcase(yyruleno==175);
#line 568 "parse.y"
{yygotominor.yy240 = 0;}
#line 2625 "parse.c"
        break;
      case 147: /* orderby_opt ::= ORDER BY sortlist */
      case 155: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==155);
      case 234: /* exprlist ::= nexprlist */ yytestcase(yyruleno==234);
#line 579 "parse.y"
{yygotominor.yy418 = yymsp[0].minor.yy418;}
#line 2632 "parse.c"
        break;
      case 148: /* sortlist ::= sortlist COMMA sortitem sortorder */
#line 580 "parse.y"
{
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,yymsp[-3].minor.yy418,yymsp[-1].minor.yy62);
  if( yygotominor.yy418 ) yygotominor.yy418->a[yygotominor.yy418->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy280;
}
#line 2640 "parse.c"
        break;
      case 149: /* sortlist ::= sortitem sortorder */
#line 584 "parse.y"
{
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,0,yymsp[-1].minor.yy62);
  if( yygotominor.yy418 && ALWAYS(yygotominor.yy418->a) ) yygotominor.yy418->a[0].sortOrder = (u8)yymsp[0].minor.yy280;
}
#line 2648 "parse.c"
        break;
      case 151: /* sortorder ::= ASC */
      case 153: /* sortorder ::= */ yytestcase(yyruleno==153);
#line 592 "parse.y"
{yygotominor.yy280 = SQLITE_SO_ASC;}
#line 2654 "parse.c"
        break;
      case 152: /* sortorder ::= DESC */
#line 593 "parse.y"
{yygotominor.yy280 = SQLITE_SO_DESC;}
#line 2659 "parse.c"
        break;
      case 158: /* limit_opt ::= */
#line 619 "parse.y"
{yygotominor.yy220.pLimit = 0; yygotominor.yy220.pOffset = 0;}
#line 2664 "parse.c"
        break;
      case 159: /* limit_opt ::= LIMIT expr */
#line 620 "parse.y"
{yygotominor.yy220.pLimit = yymsp[0].minor.yy370.pExpr; yygotominor.yy220.pOffset = 0;}
#line 2669 "parse.c"
        break;
      case 160: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 622 "parse.y"
{yygotominor.yy220.pLimit = yymsp[-2].minor.yy370.pExpr; yygotominor.yy220.pOffset = yymsp[0].minor.yy370.pExpr;}
#line 2674 "parse.c"
        break;
      case 161: /* limit_opt ::= LIMIT expr COMMA expr */
#line 624 "parse.y"
{yygotominor.yy220.pOffset = yymsp[-2].minor.yy370.pExpr; yygotominor.yy220.pLimit = yymsp[0].minor.yy370.pExpr;}
#line 2679 "parse.c"
        break;
      case 162: /* cmd ::= DELETE FROM fullname indexed_opt where_opt orderby_opt limit_opt */
#line 630 "parse.y"
{
  sqlite3SrcListIndexedBy(pParse, yymsp[-4].minor.yy151, &yymsp[-3].minor.yy0);
  yymsp[-2].minor.yy62 = sqlite3LimitWhere(pParse, yymsp[-4].minor.yy151, yymsp[-2].minor.yy62, yymsp[-1].minor.yy418, yymsp[0].minor.yy220.pLimit, yymsp[0].minor.yy220.pOffset, "DELETE");
  sqlite3DeleteFrom(pParse,yymsp[-4].minor.yy151,yymsp[-2].minor.yy62);
}
#line 2688 "parse.c"
        break;
      case 165: /* cmd ::= UPDATE orconf fullname indexed_opt SET setlist where_opt orderby_opt limit_opt */
#line 652 "parse.y"
{
  sqlite3SrcListIndexedBy(pParse, yymsp[-6].minor.yy151, &yymsp[-5].minor.yy0);
  sqlite3ExprListCheckLength(pParse,yymsp[-3].minor.yy418,"set list"); 
  yymsp[-2].minor.yy62 = sqlite3LimitWhere(pParse, yymsp[-6].minor.yy151, yymsp[-2].minor.yy62, yymsp[-1].minor.yy418, yymsp[0].minor.yy220.pLimit, yymsp[0].minor.yy220.pOffset, "UPDATE");
  sqlite3Update(pParse,yymsp[-6].minor.yy151,yymsp[-3].minor.yy418,yymsp[-2].minor.yy62,yymsp[-7].minor.yy354);
}
#line 2698 "parse.c"
        break;
      case 166: /* setlist ::= setlist COMMA nm EQ expr */
#line 670 "parse.y"
{
  yygotominor.yy418 = sqlite3ExprListAppend(pParse, yymsp[-4].minor.yy418, yymsp[0].minor.yy370.pExpr);
  sqlite3ExprListSetName(pParse, yygotominor.yy418, &yymsp[-2].minor.yy0, 1);
}
#line 2706 "parse.c"
        break;
      case 167: /* setlist ::= nm EQ expr */
#line 674 "parse.y"
{
  yygotominor.yy418 = sqlite3ExprListAppend(pParse, 0, yymsp[0].minor.yy370.pExpr);
  sqlite3ExprListSetName(pParse, yygotominor.yy418, &yymsp[-2].minor.yy0, 1);
}
#line 2714 "parse.c"
        break;
      case 168: /* cmd ::= insert_cmd INTO fullname inscollist_opt VALUES LP itemlist RP */
#line 683 "parse.y"
{sqlite3Insert(pParse, yymsp[-5].minor.yy151, yymsp[-1].minor.yy418, 0, yymsp[-4].minor.yy240, yymsp[-7].minor.yy354);}
#line 2719 "parse.c"
        break;
      case 169: /* cmd ::= insert_cmd INTO fullname inscollist_opt select */
#line 685 "parse.y"
{sqlite3Insert(pParse, yymsp[-2].minor.yy151, 0, yymsp[0].minor.yy375, yymsp[-1].minor.yy240, yymsp[-4].minor.yy354);}
#line 2724 "parse.c"
        break;
      case 170: /* cmd ::= insert_cmd INTO fullname inscollist_opt DEFAULT VALUES */
#line 687 "parse.y"
{sqlite3Insert(pParse, yymsp[-3].minor.yy151, 0, 0, yymsp[-2].minor.yy240, yymsp[-5].minor.yy354);}
#line 2729 "parse.c"
        break;
      case 171: /* insert_cmd ::= INSERT orconf */
#line 690 "parse.y"
{yygotominor.yy354 = yymsp[0].minor.yy354;}
#line 2734 "parse.c"
        break;
      case 172: /* insert_cmd ::= REPLACE */
#line 691 "parse.y"
{yygotominor.yy354 = OE_Replace;}
#line 2739 "parse.c"
        break;
      case 173: /* itemlist ::= itemlist COMMA expr */
      case 236: /* nexprlist ::= nexprlist COMMA expr */ yytestcase(yyruleno==236);
#line 698 "parse.y"
{yygotominor.yy418 = sqlite3ExprListAppend(pParse,yymsp[-2].minor.yy418,yymsp[0].minor.yy370.pExpr);}
#line 2745 "parse.c"
        break;
      case 174: /* itemlist ::= expr */
      case 237: /* nexprlist ::= expr */ yytestcase(yyruleno==237);
#line 700 "parse.y"
{yygotominor.yy418 = sqlite3ExprListAppend(pParse,0,yymsp[0].minor.yy370.pExpr);}
#line 2751 "parse.c"
        break;
      case 177: /* inscollist ::= inscollist COMMA nm */
#line 710 "parse.y"
{yygotominor.yy240 = sqlite3IdListAppend(pParse->db,yymsp[-2].minor.yy240,&yymsp[0].minor.yy0);}
#line 2756 "parse.c"
        break;
      case 178: /* inscollist ::= nm */
#line 712 "parse.y"
{yygotominor.yy240 = sqlite3IdListAppend(pParse->db,0,&yymsp[0].minor.yy0);}
#line 2761 "parse.c"
        break;
      case 179: /* expr ::= term */
#line 743 "parse.y"
{yygotominor.yy370 = yymsp[0].minor.yy370;}
#line 2766 "parse.c"
        break;
      case 180: /* expr ::= LP expr RP */
#line 744 "parse.y"
{yygotominor.yy370.pExpr = yymsp[-1].minor.yy370.pExpr; spanSet(&yygotominor.yy370,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0);}
#line 2771 "parse.c"
        break;
      case 181: /* term ::= NULL */
      case 186: /* term ::= INTEGER|FLOAT|BLOB */ yytestcase(yyruleno==186);
      case 187: /* term ::= STRING */ yytestcase(yyruleno==187);
#line 745 "parse.y"
{spanExpr(&yygotominor.yy370, pParse, yymsp[0].major, &yymsp[0].minor.yy0);}
#line 2778 "parse.c"
        break;
      case 182: /* expr ::= id */
      case 183: /* expr ::= JOIN_KW */ yytestcase(yyruleno==183);
#line 746 "parse.y"
{spanExpr(&yygotominor.yy370, pParse, TK_ID, &yymsp[0].minor.yy0);}
#line 2784 "parse.c"
        break;
      case 184: /* expr ::= nm DOT nm */
#line 748 "parse.y"
{
  Expr *temp1 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *temp2 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_DOT, temp1, temp2, 0);
  spanSet(&yygotominor.yy370,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2794 "parse.c"
        break;
      case 185: /* expr ::= nm DOT nm DOT nm */
#line 754 "parse.y"
{
  Expr *temp1 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-4].minor.yy0);
  Expr *temp2 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *temp3 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);
  Expr *temp4 = sqlite3PExpr(pParse, TK_DOT, temp2, temp3, 0);
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_DOT, temp1, temp4, 0);
  spanSet(&yygotominor.yy370,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2806 "parse.c"
        break;
      case 188: /* expr ::= REGISTER */
#line 764 "parse.y"
{
  /* When doing a nested parse, one can include terms in an expression
  ** that look like this:   #1 #2 ...  These terms refer to registers
  ** in the virtual machine.  #N is the N-th register. */
  if( pParse->nested==0 ){
    sqlite3ErrorMsg(pParse, "near \"%T\": syntax error", &yymsp[0].minor.yy0);
    yygotominor.yy370.pExpr = 0;
  }else{
    yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_REGISTER, 0, 0, &yymsp[0].minor.yy0);
    if( yygotominor.yy370.pExpr ) sqlite3GetInt32(&yymsp[0].minor.yy0.z[1], &yygotominor.yy370.pExpr->iTable);
  }
  spanSet(&yygotominor.yy370, &yymsp[0].minor.yy0, &yymsp[0].minor.yy0);
}
#line 2823 "parse.c"
        break;
      case 189: /* expr ::= VARIABLE */
#line 777 "parse.y"
{
  spanExpr(&yygotominor.yy370, pParse, TK_VARIABLE, &yymsp[0].minor.yy0);
  sqlite3ExprAssignVarNumber(pParse, yygotominor.yy370.pExpr);
  spanSet(&yygotominor.yy370, &yymsp[0].minor.yy0, &yymsp[0].minor.yy0);
}
#line 2832 "parse.c"
        break;
      case 190: /* expr ::= expr COLLATE ids */
#line 782 "parse.y"
{
  yygotominor.yy370.pExpr = sqlite3ExprSetCollByToken(pParse, yymsp[-2].minor.yy370.pExpr, &yymsp[0].minor.yy0);
  yygotominor.yy370.zStart = yymsp[-2].minor.yy370.zStart;
  yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 2841 "parse.c"
        break;
      case 191: /* expr ::= CAST LP expr AS typetoken RP */
#line 788 "parse.y"
{
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_CAST, yymsp[-3].minor.yy370.pExpr, 0, &yymsp[-1].minor.yy0);
  spanSet(&yygotominor.yy370,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2849 "parse.c"
        break;
      case 192: /* expr ::= ID LP distinct exprlist RP */
#line 793 "parse.y"
{
  if( yymsp[-1].minor.yy418 && yymsp[-1].minor.yy418->nExpr>pParse->db->aLimit[SQLITE_LIMIT_FUNCTION_ARG] ){
    sqlite3ErrorMsg(pParse, "too many arguments on function %T", &yymsp[-4].minor.yy0);
  }
  yygotominor.yy370.pExpr = sqlite3ExprFunction(pParse, yymsp[-1].minor.yy418, &yymsp[-4].minor.yy0);
  spanSet(&yygotominor.yy370,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy280 && yygotominor.yy370.pExpr ){
    yygotominor.yy370.pExpr->flags |= EP_Distinct;
  }
}
#line 2863 "parse.c"
        break;
      case 193: /* expr ::= ID LP STAR RP */
#line 803 "parse.y"
{
  yygotominor.yy370.pExpr = sqlite3ExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yygotominor.yy370,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2871 "parse.c"
        break;
      case 194: /* term ::= CTIME_KW */
#line 807 "parse.y"
{
  /* The CURRENT_TIME, CURRENT_DATE, and CURRENT_TIMESTAMP values are
  ** treated as functions that return constants */
  yygotominor.yy370.pExpr = sqlite3ExprFunction(pParse, 0,&yymsp[0].minor.yy0);
  if( yygotominor.yy370.pExpr ){
    yygotominor.yy370.pExpr->op = TK_CONST_FUNC;  
  }
  spanSet(&yygotominor.yy370, &yymsp[0].minor.yy0, &yymsp[0].minor.yy0);
}
#line 2884 "parse.c"
        break;
      case 195: /* expr ::= expr AND expr */
      case 196: /* expr ::= expr OR expr */ yytestcase(yyruleno==196);
      case 197: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==197);
      case 198: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==198);
      case 199: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==199);
      case 200: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==200);
      case 201: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==201);
      case 202: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==202);
#line 834 "parse.y"
{spanBinaryExpr(&yygotominor.yy370,pParse,yymsp[-1].major,&yymsp[-2].minor.yy370,&yymsp[0].minor.yy370);}
#line 2896 "parse.c"
        break;
      case 203: /* likeop ::= LIKE_KW */
      case 205: /* likeop ::= MATCH */ yytestcase(yyruleno==205);
#line 847 "parse.y"
{yygotominor.yy222.eOperator = yymsp[0].minor.yy0; yygotominor.yy222.not = 0;}
#line 2902 "parse.c"
        break;
      case 204: /* likeop ::= NOT LIKE_KW */
      case 206: /* likeop ::= NOT MATCH */ yytestcase(yyruleno==206);
#line 848 "parse.y"
{yygotominor.yy222.eOperator = yymsp[0].minor.yy0; yygotominor.yy222.not = 1;}
#line 2908 "parse.c"
        break;
      case 207: /* expr ::= expr likeop expr */
#line 851 "parse.y"
{
  ExprList *pList;
  pList = sqlite3ExprListAppend(pParse,0, yymsp[0].minor.yy370.pExpr);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[-2].minor.yy370.pExpr);
  yygotominor.yy370.pExpr = sqlite3ExprFunction(pParse, pList, &yymsp[-1].minor.yy222.eOperator);
  if( yymsp[-1].minor.yy222.not ) yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy370.pExpr, 0, 0);
  yygotominor.yy370.zStart = yymsp[-2].minor.yy370.zStart;
  yygotominor.yy370.zEnd = yymsp[0].minor.yy370.zEnd;
  if( yygotominor.yy370.pExpr ) yygotominor.yy370.pExpr->flags |= EP_InfixFunc;
}
#line 2922 "parse.c"
        break;
      case 208: /* expr ::= expr likeop expr ESCAPE expr */
#line 861 "parse.y"
{
  ExprList *pList;
  pList = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy370.pExpr);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[-4].minor.yy370.pExpr);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[0].minor.yy370.pExpr);
  yygotominor.yy370.pExpr = sqlite3ExprFunction(pParse, pList, &yymsp[-3].minor.yy222.eOperator);
  if( yymsp[-3].minor.yy222.not ) yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy370.pExpr, 0, 0);
  yygotominor.yy370.zStart = yymsp[-4].minor.yy370.zStart;
  yygotominor.yy370.zEnd = yymsp[0].minor.yy370.zEnd;
  if( yygotominor.yy370.pExpr ) yygotominor.yy370.pExpr->flags |= EP_InfixFunc;
}
#line 2937 "parse.c"
        break;
      case 209: /* expr ::= expr ISNULL|NOTNULL */
#line 889 "parse.y"
{spanUnaryPostfix(&yygotominor.yy370,pParse,yymsp[0].major,&yymsp[-1].minor.yy370,&yymsp[0].minor.yy0);}
#line 2942 "parse.c"
        break;
      case 210: /* expr ::= expr NOT NULL */
#line 890 "parse.y"
{spanUnaryPostfix(&yygotominor.yy370,pParse,TK_NOTNULL,&yymsp[-2].minor.yy370,&yymsp[0].minor.yy0);}
#line 2947 "parse.c"
        break;
      case 211: /* expr ::= expr IS expr */
#line 911 "parse.y"
{
  spanBinaryExpr(&yygotominor.yy370,pParse,TK_IS,&yymsp[-2].minor.yy370,&yymsp[0].minor.yy370);
  binaryToUnaryIfNull(pParse, yymsp[0].minor.yy370.pExpr, yygotominor.yy370.pExpr, TK_ISNULL);
}
#line 2955 "parse.c"
        break;
      case 212: /* expr ::= expr IS NOT expr */
#line 915 "parse.y"
{
  spanBinaryExpr(&yygotominor.yy370,pParse,TK_ISNOT,&yymsp[-3].minor.yy370,&yymsp[0].minor.yy370);
  binaryToUnaryIfNull(pParse, yymsp[0].minor.yy370.pExpr, yygotominor.yy370.pExpr, TK_NOTNULL);
}
#line 2963 "parse.c"
        break;
      case 213: /* expr ::= NOT expr */
      case 214: /* expr ::= BITNOT expr */ yytestcase(yyruleno==214);
#line 938 "parse.y"
{spanUnaryPrefix(&yygotominor.yy370,pParse,yymsp[-1].major,&yymsp[0].minor.yy370,&yymsp[-1].minor.yy0);}
#line 2969 "parse.c"
        break;
      case 215: /* expr ::= MINUS expr */
#line 941 "parse.y"
{spanUnaryPrefix(&yygotominor.yy370,pParse,TK_UMINUS,&yymsp[0].minor.yy370,&yymsp[-1].minor.yy0);}
#line 2974 "parse.c"
        break;
      case 216: /* expr ::= PLUS expr */
#line 943 "parse.y"
{spanUnaryPrefix(&yygotominor.yy370,pParse,TK_UPLUS,&yymsp[0].minor.yy370,&yymsp[-1].minor.yy0);}
#line 2979 "parse.c"
        break;
      case 219: /* expr ::= expr between_op expr AND expr */
#line 948 "parse.y"
{
  ExprList *pList = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy370.pExpr);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[0].minor.yy370.pExpr);
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy370.pExpr, 0, 0);
  if( yygotominor.yy370.pExpr ){
    yygotominor.yy370.pExpr->x.pList = pList;
  }else{
    sqlite3ExprListDelete(pParse->db, pList);
  } 
  if( yymsp[-3].minor.yy280 ) yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy370.pExpr, 0, 0);
  yygotominor.yy370.zStart = yymsp[-4].minor.yy370.zStart;
  yygotominor.yy370.zEnd = yymsp[0].minor.yy370.zEnd;
}
#line 2996 "parse.c"
        break;
      case 222: /* expr ::= expr in_op LP exprlist RP */
#line 965 "parse.y"
{
    if( yymsp[-1].minor.yy418==0 ){
      /* Expressions of the form
      **
      **      expr1 IN ()
      **      expr1 NOT IN ()
      **
      ** simplify to constants 0 (false) and 1 (true), respectively,
      ** regardless of the value of expr1.
      */
      yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_INTEGER, 0, 0, &sqlite3IntTokens[yymsp[-3].minor.yy280]);
      sqlite3ExprDelete(pParse->db, yymsp[-4].minor.yy370.pExpr);
    }else{
      yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_IN, yymsp[-4].minor.yy370.pExpr, 0, 0);
      if( yygotominor.yy370.pExpr ){
        yygotominor.yy370.pExpr->x.pList = yymsp[-1].minor.yy418;
        sqlite3ExprSetHeight(pParse, yygotominor.yy370.pExpr);
      }else{
        sqlite3ExprListDelete(pParse->db, yymsp[-1].minor.yy418);
      }
      if( yymsp[-3].minor.yy280 ) yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy370.pExpr, 0, 0);
    }
    yygotominor.yy370.zStart = yymsp[-4].minor.yy370.zStart;
    yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
  }
#line 3025 "parse.c"
        break;
      case 223: /* expr ::= LP select RP */
#line 990 "parse.y"
{
    yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_SELECT, 0, 0, 0);
    if( yygotominor.yy370.pExpr ){
      yygotominor.yy370.pExpr->x.pSelect = yymsp[-1].minor.yy375;
      ExprSetProperty(yygotominor.yy370.pExpr, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy370.pExpr);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy375);
    }
    yygotominor.yy370.zStart = yymsp[-2].minor.yy0.z;
    yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
  }
#line 3041 "parse.c"
        break;
      case 224: /* expr ::= expr in_op LP select RP */
#line 1002 "parse.y"
{
    yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_IN, yymsp[-4].minor.yy370.pExpr, 0, 0);
    if( yygotominor.yy370.pExpr ){
      yygotominor.yy370.pExpr->x.pSelect = yymsp[-1].minor.yy375;
      ExprSetProperty(yygotominor.yy370.pExpr, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy370.pExpr);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy375);
    }
    if( yymsp[-3].minor.yy280 ) yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy370.pExpr, 0, 0);
    yygotominor.yy370.zStart = yymsp[-4].minor.yy370.zStart;
    yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
  }
#line 3058 "parse.c"
        break;
      case 225: /* expr ::= expr in_op nm dbnm */
#line 1015 "parse.y"
{
    SrcList *pSrc = sqlite3SrcListAppend(pParse->db, 0,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0);
    yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_IN, yymsp[-3].minor.yy370.pExpr, 0, 0);
    if( yygotominor.yy370.pExpr ){
      yygotominor.yy370.pExpr->x.pSelect = sqlite3SelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
      ExprSetProperty(yygotominor.yy370.pExpr, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy370.pExpr);
    }else{
      sqlite3SrcListDelete(pParse->db, pSrc);
    }
    if( yymsp[-2].minor.yy280 ) yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy370.pExpr, 0, 0);
    yygotominor.yy370.zStart = yymsp[-3].minor.yy370.zStart;
    yygotominor.yy370.zEnd = yymsp[0].minor.yy0.z ? &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] : &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
  }
#line 3076 "parse.c"
        break;
      case 226: /* expr ::= EXISTS LP select RP */
#line 1029 "parse.y"
{
    Expr *p = yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_EXISTS, 0, 0, 0);
    if( p ){
      p->x.pSelect = yymsp[-1].minor.yy375;
      ExprSetProperty(p, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, p);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy375);
    }
    yygotominor.yy370.zStart = yymsp[-3].minor.yy0.z;
    yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
  }
#line 3092 "parse.c"
        break;
      case 227: /* expr ::= CASE case_operand case_exprlist case_else END */
#line 1044 "parse.y"
{
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_CASE, yymsp[-3].minor.yy62, yymsp[-1].minor.yy62, 0);
  if( yygotominor.yy370.pExpr ){
    yygotominor.yy370.pExpr->x.pList = yymsp[-2].minor.yy418;
    sqlite3ExprSetHeight(pParse, yygotominor.yy370.pExpr);
  }else{
    sqlite3ExprListDelete(pParse->db, yymsp[-2].minor.yy418);
  }
  yygotominor.yy370.zStart = yymsp[-4].minor.yy0.z;
  yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3107 "parse.c"
        break;
      case 228: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1057 "parse.y"
{
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy418, yymsp[-2].minor.yy370.pExpr);
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,yygotominor.yy418, yymsp[0].minor.yy370.pExpr);
}
#line 3115 "parse.c"
        break;
      case 229: /* case_exprlist ::= WHEN expr THEN expr */
#line 1061 "parse.y"
{
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy370.pExpr);
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,yygotominor.yy418, yymsp[0].minor.yy370.pExpr);
}
#line 3123 "parse.c"
        break;
      case 238: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm dbnm ON nm LP idxlist RP */
#line 1090 "parse.y"
{
  sqlite3CreateIndex(pParse, &yymsp[-6].minor.yy0, &yymsp[-5].minor.yy0, 
                     sqlite3SrcListAppend(pParse->db,0,&yymsp[-3].minor.yy0,0), yymsp[-1].minor.yy418, yymsp[-9].minor.yy280,
                      &yymsp[-10].minor.yy0, &yymsp[0].minor.yy0, SQLITE_SO_ASC, yymsp[-7].minor.yy280);
}
#line 3132 "parse.c"
        break;
      case 239: /* uniqueflag ::= UNIQUE */
      case 291: /* raisetype ::= ABORT */ yytestcase(yyruleno==291);
#line 1097 "parse.y"
{yygotominor.yy280 = OE_Abort;}
#line 3138 "parse.c"
        break;
      case 240: /* uniqueflag ::= */
#line 1098 "parse.y"
{yygotominor.yy280 = OE_None;}
#line 3143 "parse.c"
        break;
      case 243: /* idxlist ::= idxlist COMMA nm collate sortorder */
#line 1107 "parse.y"
{
  Expr *p = 0;
  if( yymsp[-1].minor.yy0.n>0 ){
    p = sqlite3Expr(pParse->db, TK_COLUMN, 0);
    sqlite3ExprSetCollByToken(pParse, p, &yymsp[-1].minor.yy0);
  }
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy418, p);
  sqlite3ExprListSetName(pParse,yygotominor.yy418,&yymsp[-2].minor.yy0,1);
  sqlite3ExprListCheckLength(pParse, yygotominor.yy418, "index");
  if( yygotominor.yy418 ) yygotominor.yy418->a[yygotominor.yy418->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy280;
}
#line 3158 "parse.c"
        break;
      case 244: /* idxlist ::= nm collate sortorder */
#line 1118 "parse.y"
{
  Expr *p = 0;
  if( yymsp[-1].minor.yy0.n>0 ){
    p = sqlite3PExpr(pParse, TK_COLUMN, 0, 0, 0);
    sqlite3ExprSetCollByToken(pParse, p, &yymsp[-1].minor.yy0);
  }
  yygotominor.yy418 = sqlite3ExprListAppend(pParse,0, p);
  sqlite3ExprListSetName(pParse, yygotominor.yy418, &yymsp[-2].minor.yy0, 1);
  sqlite3ExprListCheckLength(pParse, yygotominor.yy418, "index");
  if( yygotominor.yy418 ) yygotominor.yy418->a[yygotominor.yy418->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy280;
}
#line 3173 "parse.c"
        break;
      case 245: /* collate ::= */
#line 1131 "parse.y"
{yygotominor.yy0.z = 0; yygotominor.yy0.n = 0;}
#line 3178 "parse.c"
        break;
      case 247: /* cmd ::= DROP INDEX ifexists fullname */
#line 1137 "parse.y"
{sqlite3DropIndex(pParse, yymsp[0].minor.yy151, yymsp[-1].minor.yy280);}
#line 3183 "parse.c"
        break;
      case 248: /* cmd ::= PRAGMA nm dbnm */
#line 1151 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,0,0);}
#line 3188 "parse.c"
        break;
      case 249: /* cmd ::= PRAGMA nm dbnm EQ nmnum */
#line 1152 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0);}
#line 3193 "parse.c"
        break;
      case 250: /* cmd ::= PRAGMA nm dbnm LP nmnum RP */
#line 1153 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);}
#line 3198 "parse.c"
        break;
      case 251: /* cmd ::= PRAGMA nm dbnm EQ minus_num */
#line 1155 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,1);}
#line 3203 "parse.c"
        break;
      case 252: /* cmd ::= PRAGMA nm dbnm LP minus_num RP */
#line 1157 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,1);}
#line 3208 "parse.c"
        break;
      case 263: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1175 "parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  sqlite3FinishTrigger(pParse, yymsp[-1].minor.yy360, &all);
}
#line 3218 "parse.c"
        break;
      case 264: /* trigger_decl ::= temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1184 "parse.y"
{
  sqlite3BeginTrigger(pParse, &yymsp[-7].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy280, yymsp[-4].minor.yy30.a, yymsp[-4].minor.yy30.b, yymsp[-2].minor.yy151, yymsp[0].minor.yy62, yymsp[-10].minor.yy280, yymsp[-8].minor.yy280);
  yygotominor.yy0 = (yymsp[-6].minor.yy0.n==0?yymsp[-7].minor.yy0:yymsp[-6].minor.yy0);
}
#line 3226 "parse.c"
        break;
      case 265: /* trigger_time ::= BEFORE */
      case 268: /* trigger_time ::= */ yytestcase(yyruleno==268);
#line 1190 "parse.y"
{ yygotominor.yy280 = TK_BEFORE; }
#line 3232 "parse.c"
        break;
      case 266: /* trigger_time ::= AFTER */
#line 1191 "parse.y"
{ yygotominor.yy280 = TK_AFTER;  }
#line 3237 "parse.c"
        break;
      case 267: /* trigger_time ::= INSTEAD OF */
#line 1192 "parse.y"
{ yygotominor.yy280 = TK_INSTEAD;}
#line 3242 "parse.c"
        break;
      case 269: /* trigger_event ::= DELETE|INSERT */
      case 270: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==270);
#line 1197 "parse.y"
{yygotominor.yy30.a = yymsp[0].major; yygotominor.yy30.b = 0;}
#line 3248 "parse.c"
        break;
      case 271: /* trigger_event ::= UPDATE OF inscollist */
#line 1199 "parse.y"
{yygotominor.yy30.a = TK_UPDATE; yygotominor.yy30.b = yymsp[0].minor.yy240;}
#line 3253 "parse.c"
        break;
      case 274: /* when_clause ::= */
#line 1206 "parse.y"
{ yygotominor.yy62 = 0; }
#line 3258 "parse.c"
        break;
      case 275: /* when_clause ::= WHEN expr */
#line 1207 "parse.y"
{ yygotominor.yy62 = yymsp[0].minor.yy370.pExpr; }
#line 3263 "parse.c"
        break;
      case 276: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1211 "parse.y"
{
  assert( yymsp[-2].minor.yy360!=0 );
  yymsp[-2].minor.yy360->pLast->pNext = yymsp[-1].minor.yy360;
  yymsp[-2].minor.yy360->pLast = yymsp[-1].minor.yy360;
  yygotominor.yy360 = yymsp[-2].minor.yy360;
}
#line 3273 "parse.c"
        break;
      case 277: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1217 "parse.y"
{ 
  assert( yymsp[-1].minor.yy360!=0 );
  yymsp[-1].minor.yy360->pLast = yymsp[-1].minor.yy360;
  yygotominor.yy360 = yymsp[-1].minor.yy360;
}
#line 3282 "parse.c"
        break;
      case 279: /* trnm ::= nm DOT nm */
#line 1229 "parse.y"
{
  yygotominor.yy0 = yymsp[0].minor.yy0;
  sqlite3ErrorMsg(pParse, 
        "qualified table names are not allowed on INSERT, UPDATE, and DELETE "
        "statements within triggers");
}
#line 3292 "parse.c"
        break;
      case 281: /* tridxby ::= INDEXED BY nm */
#line 1241 "parse.y"
{
  sqlite3ErrorMsg(pParse,
        "the INDEXED BY clause is not allowed on UPDATE or DELETE statements "
        "within triggers");
}
#line 3301 "parse.c"
        break;
      case 282: /* tridxby ::= NOT INDEXED */
#line 1246 "parse.y"
{
  sqlite3ErrorMsg(pParse,
        "the NOT INDEXED clause is not allowed on UPDATE or DELETE statements "
        "within triggers");
}
#line 3310 "parse.c"
        break;
      case 283: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1259 "parse.y"
{ yygotominor.yy360 = sqlite3TriggerUpdateStep(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy418, yymsp[0].minor.yy62, yymsp[-5].minor.yy354); }
#line 3315 "parse.c"
        break;
      case 284: /* trigger_cmd ::= insert_cmd INTO trnm inscollist_opt VALUES LP itemlist RP */
#line 1264 "parse.y"
{yygotominor.yy360 = sqlite3TriggerInsertStep(pParse->db, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy240, yymsp[-1].minor.yy418, 0, yymsp[-7].minor.yy354);}
#line 3320 "parse.c"
        break;
      case 285: /* trigger_cmd ::= insert_cmd INTO trnm inscollist_opt select */
#line 1267 "parse.y"
{yygotominor.yy360 = sqlite3TriggerInsertStep(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy240, 0, yymsp[0].minor.yy375, yymsp[-4].minor.yy354);}
#line 3325 "parse.c"
        break;
      case 286: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1271 "parse.y"
{yygotominor.yy360 = sqlite3TriggerDeleteStep(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy62);}
#line 3330 "parse.c"
        break;
      case 287: /* trigger_cmd ::= select */
#line 1274 "parse.y"
{yygotominor.yy360 = sqlite3TriggerSelectStep(pParse->db, yymsp[0].minor.yy375); }
#line 3335 "parse.c"
        break;
      case 288: /* expr ::= RAISE LP IGNORE RP */
#line 1277 "parse.y"
{
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_RAISE, 0, 0, 0); 
  if( yygotominor.yy370.pExpr ){
    yygotominor.yy370.pExpr->affinity = OE_Ignore;
  }
  yygotominor.yy370.zStart = yymsp[-3].minor.yy0.z;
  yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3347 "parse.c"
        break;
      case 289: /* expr ::= RAISE LP raisetype COMMA nm RP */
#line 1285 "parse.y"
{
  yygotominor.yy370.pExpr = sqlite3PExpr(pParse, TK_RAISE, 0, 0, &yymsp[-1].minor.yy0); 
  if( yygotominor.yy370.pExpr ) {
    yygotominor.yy370.pExpr->affinity = (char)yymsp[-3].minor.yy280;
  }
  yygotominor.yy370.zStart = yymsp[-5].minor.yy0.z;
  yygotominor.yy370.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3359 "parse.c"
        break;
      case 290: /* raisetype ::= ROLLBACK */
#line 1296 "parse.y"
{yygotominor.yy280 = OE_Rollback;}
#line 3364 "parse.c"
        break;
      case 292: /* raisetype ::= FAIL */
#line 1298 "parse.y"
{yygotominor.yy280 = OE_Fail;}
#line 3369 "parse.c"
        break;
      case 293: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1303 "parse.y"
{
  sqlite3DropTrigger(pParse,yymsp[0].minor.yy151,yymsp[-1].minor.yy280);
}
#line 3376 "parse.c"
        break;
      case 294: /* cmd ::= REINDEX */
#line 1328 "parse.y"
{sqlite3Reindex(pParse, 0, 0);}
#line 3381 "parse.c"
        break;
      case 295: /* cmd ::= REINDEX nm dbnm */
#line 1329 "parse.y"
{sqlite3Reindex(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);}
#line 3386 "parse.c"
        break;
      case 296: /* cmd ::= ANALYZE */
#line 1334 "parse.y"
{sqlite3Analyze(pParse, 0, 0);}
#line 3391 "parse.c"
        break;
      case 297: /* cmd ::= ANALYZE nm dbnm */
#line 1335 "parse.y"
{sqlite3Analyze(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);}
#line 3396 "parse.c"
        break;
      case 298: /* cmd ::= create_vtab */
#line 1356 "parse.y"
{sqlite3VtabFinishParse(pParse,0);}
#line 3401 "parse.c"
        break;
      case 299: /* cmd ::= create_vtab LP vtabarglist RP */
#line 1357 "parse.y"
{sqlite3VtabFinishParse(pParse,&yymsp[0].minor.yy0);}
#line 3406 "parse.c"
        break;
      case 300: /* create_vtab ::= createkw VIRTUAL TABLE nm dbnm USING nm */
#line 1358 "parse.y"
{
    sqlite3VtabBeginParse(pParse, &yymsp[-3].minor.yy0, &yymsp[-2].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3413 "parse.c"
        break;
      case 303: /* vtabarg ::= */
#line 1363 "parse.y"
{sqlite3VtabArgInit(pParse);}
#line 3418 "parse.c"
        break;
      case 305: /* vtabargtoken ::= ANY */
      case 306: /* vtabargtoken ::= lp anylist RP */ yytestcase(yyruleno==306);
      case 307: /* lp ::= LP */ yytestcase(yyruleno==307);
#line 1365 "parse.y"
{sqlite3VtabArgExtend(pParse,&yymsp[0].minor.yy0);}
#line 3425 "parse.c"
        break;
      default:
      /* (0) input ::= cmdlist */ yytestcase(yyruleno==0);
      /* (1) cmdlist ::= cmdlist ecmd */ yytestcase(yyruleno==1);
      /* (2) cmdlist ::= ecmd */ yytestcase(yyruleno==2);
      /* (3) ecmd ::= SEMI */ yytestcase(yyruleno==3);
      /* (4) ecmd ::= explain cmdx SEMI */ yytestcase(yyruleno==4);
      /* (8) trans_opt ::= */ yytestcase(yyruleno==8);
      /* (9) trans_opt ::= TRANSACTION */ yytestcase(yyruleno==9);
      /* (10) trans_opt ::= TRANSACTION nm */ yytestcase(yyruleno==10);
      /* (18) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==18);
      /* (19) savepoint_opt ::= */ yytestcase(yyruleno==19);
      /* (23) cmd ::= create_table create_table_args */ yytestcase(yyruleno==23);
      /* (31) columnlist ::= columnlist COMMA column */ yytestcase(yyruleno==31);
      /* (32) columnlist ::= column */ yytestcase(yyruleno==32);
      /* (41) type ::= */ yytestcase(yyruleno==41);
      /* (48) signed ::= plus_num */ yytestcase(yyruleno==48);
      /* (49) signed ::= minus_num */ yytestcase(yyruleno==49);
      /* (50) carglist ::= carglist carg */ yytestcase(yyruleno==50);
      /* (51) carglist ::= */ yytestcase(yyruleno==51);
      /* (52) carg ::= CONSTRAINT nm ccons */ yytestcase(yyruleno==52);
      /* (53) carg ::= ccons */ yytestcase(yyruleno==53);
      /* (59) ccons ::= NULL onconf */ yytestcase(yyruleno==59);
      /* (87) conslist ::= conslist COMMA tcons */ yytestcase(yyruleno==87);
      /* (88) conslist ::= conslist tcons */ yytestcase(yyruleno==88);
      /* (89) conslist ::= tcons */ yytestcase(yyruleno==89);
      /* (90) tcons ::= CONSTRAINT nm */ yytestcase(yyruleno==90);
      /* (261) plus_opt ::= PLUS */ yytestcase(yyruleno==261);
      /* (262) plus_opt ::= */ yytestcase(yyruleno==262);
      /* (272) foreach_clause ::= */ yytestcase(yyruleno==272);
      /* (273) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==273);
      /* (280) tridxby ::= */ yytestcase(yyruleno==280);
      /* (301) vtabarglist ::= vtabarg */ yytestcase(yyruleno==301);
      /* (302) vtabarglist ::= vtabarglist COMMA vtabarg */ yytestcase(yyruleno==302);
      /* (304) vtabarg ::= vtabarg vtabargtoken */ yytestcase(yyruleno==304);
      /* (308) anylist ::= */ yytestcase(yyruleno==308);
      /* (309) anylist ::= anylist LP anylist RP */ yytestcase(yyruleno==309);
      /* (310) anylist ::= anylist ANY */ yytestcase(yyruleno==310);
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlite3ParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  sqlite3ParserARG_FETCH;
#define TOKEN (yyminor.yy0)
#line 32 "parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  sqlite3ErrorMsg(pParse, "near \"%T\": syntax error", &TOKEN);
  pParse->parseError = 1;
#line 3529 "parse.c"
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlite3ParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlite3ParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3Parser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlite3ParserTOKENTYPE yyminor       /* The value for the token */
  sqlite3ParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  sqlite3ParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor,yyminorunion);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
